# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .add_chapter_response_model import AddChapterResponseModel
from .add_knowledge_base_response_model import AddKnowledgeBaseResponseModel
from .add_project_request import AddProjectRequest
from .add_project_response_model import AddProjectResponseModel
from .add_pronunciation_dictionary_response_model import AddPronunciationDictionaryResponseModel
from .add_pronunciation_dictionary_response_model_permission_on_resource import (
    AddPronunciationDictionaryResponseModelPermissionOnResource,
)
from .add_sharing_voice_request import AddSharingVoiceRequest
from .add_voice_ivc_response_model import AddVoiceIvcResponseModel
from .add_voice_response_model import AddVoiceResponseModel
from .add_workspace_group_member_response_model import AddWorkspaceGroupMemberResponseModel
from .add_workspace_invite_response_model import AddWorkspaceInviteResponseModel
from .additional_format_response_model import AdditionalFormatResponseModel
from .additional_formats import AdditionalFormats
from .age import Age
from .agent_call_limits import AgentCallLimits
from .agent_config import AgentConfig
from .agent_config_override import AgentConfigOverride
from .agent_config_override_config import AgentConfigOverrideConfig
from .agent_metadata_response_model import AgentMetadataResponseModel
from .agent_platform_settings_request_model import AgentPlatformSettingsRequestModel
from .agent_platform_settings_response_model import AgentPlatformSettingsResponseModel
from .agent_simulated_chat_test_response_model import AgentSimulatedChatTestResponseModel
from .agent_summary_response_model import AgentSummaryResponseModel
from .agent_testing_settings import AgentTestingSettings
from .agent_transfer import AgentTransfer
from .agent_workspace_overrides_input import AgentWorkspaceOverridesInput
from .agent_workspace_overrides_output import AgentWorkspaceOverridesOutput
from .alignment import Alignment
from .allowlist_item import AllowlistItem
from .array_json_schema_property_input import ArrayJsonSchemaPropertyInput
from .array_json_schema_property_input_items import ArrayJsonSchemaPropertyInputItems
from .array_json_schema_property_output import ArrayJsonSchemaPropertyOutput
from .array_json_schema_property_output_items import ArrayJsonSchemaPropertyOutputItems
from .asr_conversational_config import AsrConversationalConfig
from .asr_input_format import AsrInputFormat
from .asr_provider import AsrProvider
from .asr_quality import AsrQuality
from .audio_native_create_project_response_model import AudioNativeCreateProjectResponseModel
from .audio_native_edit_content_response_model import AudioNativeEditContentResponseModel
from .audio_native_project_settings_response_model import AudioNativeProjectSettingsResponseModel
from .audio_native_project_settings_response_model_status import AudioNativeProjectSettingsResponseModelStatus
from .audio_output import AudioOutput
from .audio_output_multi import AudioOutputMulti
from .audio_with_timestamps_response import AudioWithTimestampsResponse
from .auth_connection_locator import AuthConnectionLocator
from .auth_settings import AuthSettings
from .authorization_method import AuthorizationMethod
from .bad_request_error_body import BadRequestErrorBody
from .ban_reason_type import BanReasonType
from .batch_call_detailed_response import BatchCallDetailedResponse
from .batch_call_recipient_status import BatchCallRecipientStatus
from .batch_call_response import BatchCallResponse
from .batch_call_status import BatchCallStatus
from .body_generate_a_random_voice_v_1_voice_generation_generate_voice_post_age import (
    BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostAge,
)
from .body_generate_a_random_voice_v_1_voice_generation_generate_voice_post_gender import (
    BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostGender,
)
from .breakdown_types import BreakdownTypes
from .built_in_tools_input import BuiltInToolsInput
from .built_in_tools_output import BuiltInToolsOutput
from .caption_style_character_animation_model import CaptionStyleCharacterAnimationModel
from .caption_style_character_animation_model_enter_type import CaptionStyleCharacterAnimationModelEnterType
from .caption_style_character_animation_model_exit_type import CaptionStyleCharacterAnimationModelExitType
from .caption_style_horizontal_placement_model import CaptionStyleHorizontalPlacementModel
from .caption_style_horizontal_placement_model_align import CaptionStyleHorizontalPlacementModelAlign
from .caption_style_model import CaptionStyleModel
from .caption_style_model_text_align import CaptionStyleModelTextAlign
from .caption_style_model_text_style import CaptionStyleModelTextStyle
from .caption_style_model_text_weight import CaptionStyleModelTextWeight
from .caption_style_section_animation_model import CaptionStyleSectionAnimationModel
from .caption_style_section_animation_model_enter_type import CaptionStyleSectionAnimationModelEnterType
from .caption_style_section_animation_model_exit_type import CaptionStyleSectionAnimationModelExitType
from .caption_style_template_model import CaptionStyleTemplateModel
from .caption_style_vertical_placement_model import CaptionStyleVerticalPlacementModel
from .caption_style_vertical_placement_model_align import CaptionStyleVerticalPlacementModelAlign
from .caption_style_word_animation_model import CaptionStyleWordAnimationModel
from .caption_style_word_animation_model_enter_type import CaptionStyleWordAnimationModelEnterType
from .caption_style_word_animation_model_exit_type import CaptionStyleWordAnimationModelExitType
from .chapter_content_block_extendable_node_response_model import ChapterContentBlockExtendableNodeResponseModel
from .chapter_content_block_input_model import ChapterContentBlockInputModel
from .chapter_content_block_input_model_sub_type import ChapterContentBlockInputModelSubType
from .chapter_content_block_response_model import ChapterContentBlockResponseModel
from .chapter_content_block_response_model_nodes_item import (
    ChapterContentBlockResponseModelNodesItem,
    ChapterContentBlockResponseModelNodesItem_Other,
    ChapterContentBlockResponseModelNodesItem_TtsNode,
)
from .chapter_content_block_tts_node_response_model import ChapterContentBlockTtsNodeResponseModel
from .chapter_content_input_model import ChapterContentInputModel
from .chapter_content_paragraph_tts_node_input_model import ChapterContentParagraphTtsNodeInputModel
from .chapter_content_response_model import ChapterContentResponseModel
from .chapter_response import ChapterResponse
from .chapter_snapshot_extended_response_model import ChapterSnapshotExtendedResponseModel
from .chapter_snapshot_response import ChapterSnapshotResponse
from .chapter_snapshots_response import ChapterSnapshotsResponse
from .chapter_state import ChapterState
from .chapter_statistics_response import ChapterStatisticsResponse
from .chapter_with_content_response_model import ChapterWithContentResponseModel
from .chapter_with_content_response_model_state import ChapterWithContentResponseModelState
from .character_alignment_model import CharacterAlignmentModel
from .character_alignment_response_model import CharacterAlignmentResponseModel
from .character_usage_response import CharacterUsageResponse
from .client_event import ClientEvent
from .client_tool_config_input import ClientToolConfigInput
from .client_tool_config_output import ClientToolConfigOutput
from .close_connection import CloseConnection
from .close_context import CloseContext
from .close_socket import CloseSocket
from .conv_ai_dynamic_variable import ConvAiDynamicVariable
from .conv_ai_secret_locator import ConvAiSecretLocator
from .conv_ai_stored_secret_dependencies import ConvAiStoredSecretDependencies
from .conv_ai_stored_secret_dependencies_agents_item import (
    ConvAiStoredSecretDependenciesAgentsItem,
    ConvAiStoredSecretDependenciesAgentsItem_Available,
    ConvAiStoredSecretDependenciesAgentsItem_Unknown,
)
from .conv_ai_stored_secret_dependencies_tools_item import (
    ConvAiStoredSecretDependenciesToolsItem,
    ConvAiStoredSecretDependenciesToolsItem_Available,
    ConvAiStoredSecretDependenciesToolsItem_Unknown,
)
from .conv_ai_user_secret_db_model import ConvAiUserSecretDbModel
from .conv_ai_webhooks import ConvAiWebhooks
from .conv_ai_workspace_stored_secret_config import ConvAiWorkspaceStoredSecretConfig
from .conversation_charging_common_model import ConversationChargingCommonModel
from .conversation_config import ConversationConfig
from .conversation_config_client_override_config_input import ConversationConfigClientOverrideConfigInput
from .conversation_config_client_override_config_output import ConversationConfigClientOverrideConfigOutput
from .conversation_config_client_override_input import ConversationConfigClientOverrideInput
from .conversation_config_client_override_output import ConversationConfigClientOverrideOutput
from .conversation_config_override import ConversationConfigOverride
from .conversation_config_override_config import ConversationConfigOverrideConfig
from .conversation_deletion_settings import ConversationDeletionSettings
from .conversation_history_analysis_common_model import ConversationHistoryAnalysisCommonModel
from .conversation_history_batch_call_model import ConversationHistoryBatchCallModel
from .conversation_history_eleven_assistant_common_model import ConversationHistoryElevenAssistantCommonModel
from .conversation_history_error_common_model import ConversationHistoryErrorCommonModel
from .conversation_history_evaluation_criteria_result_common_model import (
    ConversationHistoryEvaluationCriteriaResultCommonModel,
)
from .conversation_history_feedback_common_model import ConversationHistoryFeedbackCommonModel
from .conversation_history_metadata_common_model import ConversationHistoryMetadataCommonModel
from .conversation_history_metadata_common_model_phone_call import (
    ConversationHistoryMetadataCommonModelPhoneCall,
    ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking,
    ConversationHistoryMetadataCommonModelPhoneCall_Twilio,
)
from .conversation_history_rag_usage_common_model import ConversationHistoryRagUsageCommonModel
from .conversation_history_sip_trunking_phone_call_model import ConversationHistorySipTrunkingPhoneCallModel
from .conversation_history_sip_trunking_phone_call_model_direction import (
    ConversationHistorySipTrunkingPhoneCallModelDirection,
)
from .conversation_history_transcript_common_model_input import ConversationHistoryTranscriptCommonModelInput
from .conversation_history_transcript_common_model_input_role import ConversationHistoryTranscriptCommonModelInputRole
from .conversation_history_transcript_common_model_input_source_medium import (
    ConversationHistoryTranscriptCommonModelInputSourceMedium,
)
from .conversation_history_transcript_common_model_input_tool_results_item import (
    ConversationHistoryTranscriptCommonModelInputToolResultsItem,
)
from .conversation_history_transcript_common_model_output import ConversationHistoryTranscriptCommonModelOutput
from .conversation_history_transcript_common_model_output_role import ConversationHistoryTranscriptCommonModelOutputRole
from .conversation_history_transcript_common_model_output_source_medium import (
    ConversationHistoryTranscriptCommonModelOutputSourceMedium,
)
from .conversation_history_transcript_common_model_output_tool_results_item import (
    ConversationHistoryTranscriptCommonModelOutputToolResultsItem,
)
from .conversation_history_transcript_other_tools_result_common_model import (
    ConversationHistoryTranscriptOtherToolsResultCommonModel,
)
from .conversation_history_transcript_other_tools_result_common_model_type import (
    ConversationHistoryTranscriptOtherToolsResultCommonModelType,
)
from .conversation_history_transcript_system_tool_result_common_model import (
    ConversationHistoryTranscriptSystemToolResultCommonModel,
)
from .conversation_history_transcript_system_tool_result_common_model_result import (
    ConversationHistoryTranscriptSystemToolResultCommonModelResult,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_EndCallSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_LanguageDetectionSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_SkipTurnSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberSipSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberTwilioSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_VoicemailDetectionSuccess,
)
from .conversation_history_transcript_tool_call_client_details import ConversationHistoryTranscriptToolCallClientDetails
from .conversation_history_transcript_tool_call_common_model import ConversationHistoryTranscriptToolCallCommonModel
from .conversation_history_transcript_tool_call_common_model_tool_details import (
    ConversationHistoryTranscriptToolCallCommonModelToolDetails,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Client,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Mcp,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Webhook,
)
from .conversation_history_transcript_tool_call_mcp_details import ConversationHistoryTranscriptToolCallMcpDetails
from .conversation_history_transcript_tool_call_webhook_details import (
    ConversationHistoryTranscriptToolCallWebhookDetails,
)
from .conversation_history_transcript_workflow_tools_result_common_model_input import (
    ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput,
)
from .conversation_history_transcript_workflow_tools_result_common_model_output import (
    ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput,
)
from .conversation_history_twilio_phone_call_model import ConversationHistoryTwilioPhoneCallModel
from .conversation_history_twilio_phone_call_model_direction import ConversationHistoryTwilioPhoneCallModelDirection
from .conversation_initiation_client_data_config_input import ConversationInitiationClientDataConfigInput
from .conversation_initiation_client_data_config_output import ConversationInitiationClientDataConfigOutput
from .conversation_initiation_client_data_internal import ConversationInitiationClientDataInternal
from .conversation_initiation_client_data_internal_dynamic_variables_value import (
    ConversationInitiationClientDataInternalDynamicVariablesValue,
)
from .conversation_initiation_client_data_request_input import ConversationInitiationClientDataRequestInput
from .conversation_initiation_client_data_request_input_dynamic_variables_value import (
    ConversationInitiationClientDataRequestInputDynamicVariablesValue,
)
from .conversation_initiation_client_data_request_output import ConversationInitiationClientDataRequestOutput
from .conversation_initiation_client_data_request_output_dynamic_variables_value import (
    ConversationInitiationClientDataRequestOutputDynamicVariablesValue,
)
from .conversation_initiation_client_data_webhook import ConversationInitiationClientDataWebhook
from .conversation_initiation_client_data_webhook_request_headers_value import (
    ConversationInitiationClientDataWebhookRequestHeadersValue,
)
from .conversation_initiation_source import ConversationInitiationSource
from .conversation_initiation_source_info import ConversationInitiationSourceInfo
from .conversation_signed_url_response_model import ConversationSignedUrlResponseModel
from .conversation_simulation_specification import ConversationSimulationSpecification
from .conversation_simulation_specification_dynamic_variables_value import (
    ConversationSimulationSpecificationDynamicVariablesValue,
)
from .conversation_summary_response_model import ConversationSummaryResponseModel
from .conversation_summary_response_model_direction import ConversationSummaryResponseModelDirection
from .conversation_summary_response_model_status import ConversationSummaryResponseModelStatus
from .conversation_token_db_model import ConversationTokenDbModel
from .conversation_token_purpose import ConversationTokenPurpose
from .conversation_turn_metrics import ConversationTurnMetrics
from .conversational_config import ConversationalConfig
from .convert_chapter_response_model import ConvertChapterResponseModel
from .convert_project_response_model import ConvertProjectResponseModel
from .create_agent_response_model import CreateAgentResponseModel
from .create_audio_native_project_request import CreateAudioNativeProjectRequest
from .create_phone_number_response_model import CreatePhoneNumberResponseModel
from .create_previously_generated_voice_request import CreatePreviouslyGeneratedVoiceRequest
from .create_pronunciation_dictionary_response_model import CreatePronunciationDictionaryResponseModel
from .create_sip_trunk_phone_number_request import CreateSipTrunkPhoneNumberRequest
from .create_transcript_request import CreateTranscriptRequest
from .create_twilio_phone_number_request import CreateTwilioPhoneNumberRequest
from .custom_llm import CustomLlm
from .custom_llm_request_headers_value import CustomLlmRequestHeadersValue
from .dashboard_call_success_chart_model import DashboardCallSuccessChartModel
from .dashboard_criteria_chart_model import DashboardCriteriaChartModel
from .dashboard_data_collection_chart_model import DashboardDataCollectionChartModel
from .data_collection_result_common_model import DataCollectionResultCommonModel
from .delete_chapter_request import DeleteChapterRequest
from .delete_chapter_response_model import DeleteChapterResponseModel
from .delete_dubbing_response_model import DeleteDubbingResponseModel
from .delete_history_item_response import DeleteHistoryItemResponse
from .delete_project_request import DeleteProjectRequest
from .delete_project_response_model import DeleteProjectResponseModel
from .delete_sample_response import DeleteSampleResponse
from .delete_voice_response_model import DeleteVoiceResponseModel
from .delete_voice_sample_response_model import DeleteVoiceSampleResponseModel
from .delete_workspace_group_member_response_model import DeleteWorkspaceGroupMemberResponseModel
from .delete_workspace_invite_response_model import DeleteWorkspaceInviteResponseModel
from .delete_workspace_member_response_model import DeleteWorkspaceMemberResponseModel
from .dependent_available_agent_identifier import DependentAvailableAgentIdentifier
from .dependent_available_agent_identifier_access_level import DependentAvailableAgentIdentifierAccessLevel
from .dependent_available_tool_identifier import DependentAvailableToolIdentifier
from .dependent_available_tool_identifier_access_level import DependentAvailableToolIdentifierAccessLevel
from .dependent_phone_number_identifier import DependentPhoneNumberIdentifier
from .dependent_unknown_agent_identifier import DependentUnknownAgentIdentifier
from .dependent_unknown_tool_identifier import DependentUnknownToolIdentifier
from .dialogue_input import DialogueInput
from .dialogue_input_response_model import DialogueInputResponseModel
from .do_dubbing_response import DoDubbingResponse
from .document_usage_mode_enum import DocumentUsageModeEnum
from .docx_export_options import DocxExportOptions
from .dubbed_segment import DubbedSegment
from .dubbing_media_metadata import DubbingMediaMetadata
from .dubbing_media_reference import DubbingMediaReference
from .dubbing_metadata_page_response_model import DubbingMetadataPageResponseModel
from .dubbing_metadata_response import DubbingMetadataResponse
from .dubbing_render_response_model import DubbingRenderResponseModel
from .dubbing_resource import DubbingResource
from .dynamic_variable_assignment import DynamicVariableAssignment
from .dynamic_variable_update_common_model import DynamicVariableUpdateCommonModel
from .dynamic_variables_config import DynamicVariablesConfig
from .dynamic_variables_config_dynamic_variable_placeholders_value import (
    DynamicVariablesConfigDynamicVariablePlaceholdersValue,
)
from .edit_chapter_response_model import EditChapterResponseModel
from .edit_project_response_model import EditProjectResponseModel
from .edit_voice_response_model import EditVoiceResponseModel
from .edit_voice_settings_request import EditVoiceSettingsRequest
from .edit_voice_settings_response_model import EditVoiceSettingsResponseModel
from .embed_variant import EmbedVariant
from .embedding_model_enum import EmbeddingModelEnum
from .end_call_tool_config import EndCallToolConfig
from .end_call_tool_result_model import EndCallToolResultModel
from .evaluation_settings import EvaluationSettings
from .evaluation_success_result import EvaluationSuccessResult
from .export_options import (
    ExportOptions,
    ExportOptions_Docx,
    ExportOptions_Html,
    ExportOptions_Pdf,
    ExportOptions_SegmentedJson,
    ExportOptions_Srt,
    ExportOptions_Txt,
)
from .extended_subscription_response_model_billing_period import ExtendedSubscriptionResponseModelBillingPeriod
from .extended_subscription_response_model_character_refresh_period import (
    ExtendedSubscriptionResponseModelCharacterRefreshPeriod,
)
from .extended_subscription_response_model_currency import ExtendedSubscriptionResponseModelCurrency
from .feature_status_common_model import FeatureStatusCommonModel
from .features_usage_common_model import FeaturesUsageCommonModel
from .feedback_item import FeedbackItem
from .final_output import FinalOutput
from .final_output_multi import FinalOutputMulti
from .fine_tuning_response import FineTuningResponse
from .fine_tuning_response_model_state_value import FineTuningResponseModelStateValue
from .flush_context import FlushContext
from .forced_alignment_character_response_model import ForcedAlignmentCharacterResponseModel
from .forced_alignment_response_model import ForcedAlignmentResponseModel
from .forced_alignment_word_response_model import ForcedAlignmentWordResponseModel
from .gender import Gender
from .generate_voice_request import GenerateVoiceRequest
from .generation_config import GenerationConfig
from .get_agent_embed_response_model import GetAgentEmbedResponseModel
from .get_agent_knowledgebase_size_response_model import GetAgentKnowledgebaseSizeResponseModel
from .get_agent_link_response_model import GetAgentLinkResponseModel
from .get_agent_response_model import GetAgentResponseModel
from .get_agent_response_model_phone_numbers_item import (
    GetAgentResponseModelPhoneNumbersItem,
    GetAgentResponseModelPhoneNumbersItem_SipTrunk,
    GetAgentResponseModelPhoneNumbersItem_Twilio,
)
from .get_agents_page_response_model import GetAgentsPageResponseModel
from .get_audio_native_project_settings_response_model import GetAudioNativeProjectSettingsResponseModel
from .get_chapter_request import GetChapterRequest
from .get_chapter_snapshots_request import GetChapterSnapshotsRequest
from .get_chapters_request import GetChaptersRequest
from .get_chapters_response import GetChaptersResponse
from .get_conv_ai_dashboard_settings_response_model import GetConvAiDashboardSettingsResponseModel
from .get_conv_ai_dashboard_settings_response_model_charts_item import (
    GetConvAiDashboardSettingsResponseModelChartsItem,
    GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess,
    GetConvAiDashboardSettingsResponseModelChartsItem_Criteria,
    GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection,
)
from .get_conv_ai_settings_response_model import GetConvAiSettingsResponseModel
from .get_conversation_response_model import GetConversationResponseModel
from .get_conversation_response_model_status import GetConversationResponseModelStatus
from .get_conversations_page_response_model import GetConversationsPageResponseModel
from .get_knowledge_base_dependent_agents_response_model import GetKnowledgeBaseDependentAgentsResponseModel
from .get_knowledge_base_dependent_agents_response_model_agents_item import (
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown,
)
from .get_knowledge_base_file_response_model import GetKnowledgeBaseFileResponseModel
from .get_knowledge_base_list_response_model import GetKnowledgeBaseListResponseModel
from .get_knowledge_base_list_response_model_documents_item import (
    GetKnowledgeBaseListResponseModelDocumentsItem,
    GetKnowledgeBaseListResponseModelDocumentsItem_File,
    GetKnowledgeBaseListResponseModelDocumentsItem_Text,
    GetKnowledgeBaseListResponseModelDocumentsItem_Url,
)
from .get_knowledge_base_summary_file_response_model import GetKnowledgeBaseSummaryFileResponseModel
from .get_knowledge_base_summary_file_response_model_dependent_agents_item import (
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown,
)
from .get_knowledge_base_summary_text_response_model import GetKnowledgeBaseSummaryTextResponseModel
from .get_knowledge_base_summary_text_response_model_dependent_agents_item import (
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown,
)
from .get_knowledge_base_summary_url_response_model import GetKnowledgeBaseSummaryUrlResponseModel
from .get_knowledge_base_summary_url_response_model_dependent_agents_item import (
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown,
)
from .get_knowledge_base_text_response_model import GetKnowledgeBaseTextResponseModel
from .get_knowledge_base_url_response_model import GetKnowledgeBaseUrlResponseModel
from .get_library_voices_response import GetLibraryVoicesResponse
from .get_phone_number_inbound_sip_trunk_config_response_model import GetPhoneNumberInboundSipTrunkConfigResponseModel
from .get_phone_number_outbound_sip_trunk_config_response_model import GetPhoneNumberOutboundSipTrunkConfigResponseModel
from .get_phone_number_response import GetPhoneNumberResponse
from .get_phone_number_sip_trunk_response_model import GetPhoneNumberSipTrunkResponseModel
from .get_phone_number_twilio_response_model import GetPhoneNumberTwilioResponseModel
from .get_project_request import GetProjectRequest
from .get_projects_request import GetProjectsRequest
from .get_projects_response import GetProjectsResponse
from .get_pronunciation_dictionaries_metadata_response_model import GetPronunciationDictionariesMetadataResponseModel
from .get_pronunciation_dictionaries_response import GetPronunciationDictionariesResponse
from .get_pronunciation_dictionary_metadata_response import GetPronunciationDictionaryMetadataResponse
from .get_pronunciation_dictionary_metadata_response_model_permission_on_resource import (
    GetPronunciationDictionaryMetadataResponseModelPermissionOnResource,
)
from .get_pronunciation_dictionary_response import GetPronunciationDictionaryResponse
from .get_speech_history_response import GetSpeechHistoryResponse
from .get_tool_dependent_agents_response_model import GetToolDependentAgentsResponseModel
from .get_tool_dependent_agents_response_model_agents_item import (
    GetToolDependentAgentsResponseModelAgentsItem,
    GetToolDependentAgentsResponseModelAgentsItem_Available,
    GetToolDependentAgentsResponseModelAgentsItem_Unknown,
)
from .get_voices_response import GetVoicesResponse
from .get_voices_v_2_response import GetVoicesV2Response
from .get_workspace_secrets_response_model import GetWorkspaceSecretsResponseModel
from .history_alignment_response_model import HistoryAlignmentResponseModel
from .history_alignments_response_model import HistoryAlignmentsResponseModel
from .history_item_response import HistoryItemResponse
from .html_export_options import HtmlExportOptions
from .http_validation_error import HttpValidationError
from .image_avatar import ImageAvatar
from .inbound_sip_trunk_config_request_model import InboundSipTrunkConfigRequestModel
from .initialise_context import InitialiseContext
from .initialize_connection import InitializeConnection
from .initialize_connection_multi import InitializeConnectionMulti
from .integration_type import IntegrationType
from .invoice_response import InvoiceResponse
from .keep_context_alive import KeepContextAlive
from .knowledge_base_document_chunk_response_model import KnowledgeBaseDocumentChunkResponseModel
from .knowledge_base_document_metadata_response_model import KnowledgeBaseDocumentMetadataResponseModel
from .knowledge_base_document_type import KnowledgeBaseDocumentType
from .knowledge_base_locator import KnowledgeBaseLocator
from .language_added_response import LanguageAddedResponse
from .language_detection_tool_config import LanguageDetectionToolConfig
from .language_detection_tool_result_model import LanguageDetectionToolResultModel
from .language_preset_input import LanguagePresetInput
from .language_preset_output import LanguagePresetOutput
from .language_preset_translation import LanguagePresetTranslation
from .language_response import LanguageResponse
from .library_voice_response import LibraryVoiceResponse
from .library_voice_response_model_category import LibraryVoiceResponseModelCategory
from .list_mcp_tools_response_model import ListMcpToolsResponseModel
from .literal_json_schema_property import LiteralJsonSchemaProperty
from .literal_json_schema_property_constant_value import LiteralJsonSchemaPropertyConstantValue
from .literal_json_schema_property_type import LiteralJsonSchemaPropertyType
from .llm import Llm
from .llm_category_usage import LlmCategoryUsage
from .llm_input_output_tokens_usage import LlmInputOutputTokensUsage
from .llm_tokens_category_usage import LlmTokensCategoryUsage
from .llm_usage_calculator_llm_response_model import LlmUsageCalculatorLlmResponseModel
from .llm_usage_calculator_response_model import LlmUsageCalculatorResponseModel
from .llm_usage_input import LlmUsageInput
from .llm_usage_output import LlmUsageOutput
from .manual_verification_file_response import ManualVerificationFileResponse
from .manual_verification_response import ManualVerificationResponse
from .mcp_approval_policy import McpApprovalPolicy
from .mcp_server_config_input import McpServerConfigInput
from .mcp_server_config_input_request_headers_value import McpServerConfigInputRequestHeadersValue
from .mcp_server_config_input_secret_token import McpServerConfigInputSecretToken
from .mcp_server_config_input_url import McpServerConfigInputUrl
from .mcp_server_config_output import McpServerConfigOutput
from .mcp_server_config_output_request_headers_value import McpServerConfigOutputRequestHeadersValue
from .mcp_server_config_output_secret_token import McpServerConfigOutputSecretToken
from .mcp_server_config_output_url import McpServerConfigOutputUrl
from .mcp_server_metadata_response_model import McpServerMetadataResponseModel
from .mcp_server_response_model import McpServerResponseModel
from .mcp_server_response_model_dependent_agents_item import (
    McpServerResponseModelDependentAgentsItem,
    McpServerResponseModelDependentAgentsItem_Available,
    McpServerResponseModelDependentAgentsItem_Unknown,
)
from .mcp_server_transport import McpServerTransport
from .mcp_servers_response_model import McpServersResponseModel
from .mcp_tool_approval_hash import McpToolApprovalHash
from .mcp_tool_approval_policy import McpToolApprovalPolicy
from .metric_record import MetricRecord
from .metric_type import MetricType
from .model import Model
from .model_rates_response_model import ModelRatesResponseModel
from .model_response_model_concurrency_group import ModelResponseModelConcurrencyGroup
from .model_settings_response_model import ModelSettingsResponseModel
from .moderation_status_response_model import ModerationStatusResponseModel
from .moderation_status_response_model_safety_status import ModerationStatusResponseModelSafetyStatus
from .moderation_status_response_model_warning_status import ModerationStatusResponseModelWarningStatus
from .multichannel_speech_to_text_response_model import MultichannelSpeechToTextResponseModel
from .music_prompt import MusicPrompt
from .normalized_alignment import NormalizedAlignment
from .object_json_schema_property_input import ObjectJsonSchemaPropertyInput
from .object_json_schema_property_input_properties_value import ObjectJsonSchemaPropertyInputPropertiesValue
from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput
from .object_json_schema_property_output_properties_value import ObjectJsonSchemaPropertyOutputPropertiesValue
from .orb_avatar import OrbAvatar
from .outbound_call_recipient import OutboundCallRecipient
from .outbound_call_recipient_response_model import OutboundCallRecipientResponseModel
from .outbound_sip_trunk_config_request_model import OutboundSipTrunkConfigRequestModel
from .output_format import OutputFormat
from .pdf_export_options import PdfExportOptions
from .phone_number_agent_info import PhoneNumberAgentInfo
from .phone_number_transfer import PhoneNumberTransfer
from .phone_number_transfer_destination import PhoneNumberTransferDestination
from .phone_number_transfer_transfer_destination import (
    PhoneNumberTransferTransferDestination,
    PhoneNumberTransferTransferDestination_Phone,
    PhoneNumberTransferTransferDestination_SipUri,
)
from .play_dtmf_result_error_model import PlayDtmfResultErrorModel
from .play_dtmf_result_success_model import PlayDtmfResultSuccessModel
from .play_dtmf_tool_config import PlayDtmfToolConfig
from .podcast_bulletin_mode import PodcastBulletinMode
from .podcast_bulletin_mode_data import PodcastBulletinModeData
from .podcast_conversation_mode import PodcastConversationMode
from .podcast_conversation_mode_data import PodcastConversationModeData
from .podcast_project_response_model import PodcastProjectResponseModel
from .podcast_text_source import PodcastTextSource
from .podcast_url_source import PodcastUrlSource
from .post_agent_avatar_response_model import PostAgentAvatarResponseModel
from .post_workspace_secret_response_model import PostWorkspaceSecretResponseModel
from .privacy_config import PrivacyConfig
from .project_creation_meta_response_model import ProjectCreationMetaResponseModel
from .project_creation_meta_response_model_status import ProjectCreationMetaResponseModelStatus
from .project_creation_meta_response_model_type import ProjectCreationMetaResponseModelType
from .project_extended_response import ProjectExtendedResponse
from .project_extended_response_model_access_level import ProjectExtendedResponseModelAccessLevel
from .project_extended_response_model_apply_text_normalization import ProjectExtendedResponseModelApplyTextNormalization
from .project_extended_response_model_fiction import ProjectExtendedResponseModelFiction
from .project_extended_response_model_quality_preset import ProjectExtendedResponseModelQualityPreset
from .project_extended_response_model_source_type import ProjectExtendedResponseModelSourceType
from .project_extended_response_model_target_audience import ProjectExtendedResponseModelTargetAudience
from .project_response import ProjectResponse
from .project_response_model_access_level import ProjectResponseModelAccessLevel
from .project_response_model_fiction import ProjectResponseModelFiction
from .project_response_model_source_type import ProjectResponseModelSourceType
from .project_response_model_target_audience import ProjectResponseModelTargetAudience
from .project_snapshot_extended_response_model import ProjectSnapshotExtendedResponseModel
from .project_snapshot_response import ProjectSnapshotResponse
from .project_snapshots_response import ProjectSnapshotsResponse
from .project_state import ProjectState
from .prompt_agent import PromptAgent
from .prompt_agent_api_model_input import PromptAgentApiModelInput
from .prompt_agent_api_model_input_tools_item import (
    PromptAgentApiModelInputToolsItem,
    PromptAgentApiModelInputToolsItem_Client,
    PromptAgentApiModelInputToolsItem_Mcp,
    PromptAgentApiModelInputToolsItem_System,
    PromptAgentApiModelInputToolsItem_Webhook,
)
from .prompt_agent_api_model_output import PromptAgentApiModelOutput
from .prompt_agent_api_model_output_tools_item import (
    PromptAgentApiModelOutputToolsItem,
    PromptAgentApiModelOutputToolsItem_Client,
    PromptAgentApiModelOutputToolsItem_Mcp,
    PromptAgentApiModelOutputToolsItem_System,
    PromptAgentApiModelOutputToolsItem_Webhook,
)
from .prompt_agent_api_model_override import PromptAgentApiModelOverride
from .prompt_agent_api_model_override_config import PromptAgentApiModelOverrideConfig
from .prompt_agent_db_model import PromptAgentDbModel
from .prompt_evaluation_criteria import PromptEvaluationCriteria
from .pronunciation_dictionary_alias_rule_request_model import PronunciationDictionaryAliasRuleRequestModel
from .pronunciation_dictionary_locator import PronunciationDictionaryLocator
from .pronunciation_dictionary_locator_response_model import PronunciationDictionaryLocatorResponseModel
from .pronunciation_dictionary_phoneme_rule_request_model import PronunciationDictionaryPhonemeRuleRequestModel
from .pronunciation_dictionary_rules_response_model import PronunciationDictionaryRulesResponseModel
from .pronunciation_dictionary_version_locator import PronunciationDictionaryVersionLocator
from .pronunciation_dictionary_version_response_model import PronunciationDictionaryVersionResponseModel
from .pronunciation_dictionary_version_response_model_permission_on_resource import (
    PronunciationDictionaryVersionResponseModelPermissionOnResource,
)
from .pydantic_pronunciation_dictionary_version_locator import PydanticPronunciationDictionaryVersionLocator
from .query_params_json_schema import QueryParamsJsonSchema
from .rag_chunk_metadata import RagChunkMetadata
from .rag_config import RagConfig
from .rag_document_index_response_model import RagDocumentIndexResponseModel
from .rag_document_index_usage import RagDocumentIndexUsage
from .rag_document_indexes_response_model import RagDocumentIndexesResponseModel
from .rag_index_overview_embedding_model_response_model import RagIndexOverviewEmbeddingModelResponseModel
from .rag_index_overview_response_model import RagIndexOverviewResponseModel
from .rag_index_status import RagIndexStatus
from .rag_retrieval_info import RagRetrievalInfo
from .reader_resource_response_model import ReaderResourceResponseModel
from .reader_resource_response_model_resource_type import ReaderResourceResponseModelResourceType
from .realtime_voice_settings import RealtimeVoiceSettings
from .recording_response import RecordingResponse
from .remove_member_from_group_request import RemoveMemberFromGroupRequest
from .render import Render
from .render_status import RenderStatus
from .render_type import RenderType
from .request_pvc_manual_verification_response_model import RequestPvcManualVerificationResponseModel
from .resource_access_info import ResourceAccessInfo
from .resource_access_info_role import ResourceAccessInfoRole
from .resource_metadata_response_model import ResourceMetadataResponseModel
from .review_status import ReviewStatus
from .safety_common_model import SafetyCommonModel
from .safety_evaluation import SafetyEvaluation
from .safety_response_model import SafetyResponseModel
from .safety_rule import SafetyRule
from .save_voice_preview_request import SaveVoicePreviewRequest
from .secret_dependency_type import SecretDependencyType
from .segment_create_response import SegmentCreateResponse
from .segment_delete_response import SegmentDeleteResponse
from .segment_dub_response import SegmentDubResponse
from .segment_subtitle_frame import SegmentSubtitleFrame
from .segment_transcription_response import SegmentTranscriptionResponse
from .segment_translation_response import SegmentTranslationResponse
from .segment_update_response import SegmentUpdateResponse
from .segmented_json_export_options import SegmentedJsonExportOptions
from .send_text import SendText
from .send_text_multi import SendTextMulti
from .share_option_response_model import ShareOptionResponseModel
from .share_option_response_model_type import ShareOptionResponseModelType
from .similar_voice import SimilarVoice
from .similar_voice_category import SimilarVoiceCategory
from .similar_voices_for_speaker_response import SimilarVoicesForSpeakerResponse
from .sip_media_encryption_enum import SipMediaEncryptionEnum
from .sip_trunk_credentials_request_model import SipTrunkCredentialsRequestModel
from .sip_trunk_outbound_call_response import SipTrunkOutboundCallResponse
from .sip_trunk_transport_enum import SipTrunkTransportEnum
from .sip_uri_transfer_destination import SipUriTransferDestination
from .skip_turn_tool_config import SkipTurnToolConfig
from .skip_turn_tool_response_model import SkipTurnToolResponseModel
from .song_section import SongSection
from .speaker_audio_response_model import SpeakerAudioResponseModel
from .speaker_response_model import SpeakerResponseModel
from .speaker_segment import SpeakerSegment
from .speaker_separation_response_model import SpeakerSeparationResponseModel
from .speaker_separation_response_model_status import SpeakerSeparationResponseModelStatus
from .speaker_track import SpeakerTrack
from .speaker_updated_response import SpeakerUpdatedResponse
from .speech_history_item_response import SpeechHistoryItemResponse
from .speech_history_item_response_model_source import SpeechHistoryItemResponseModelSource
from .speech_history_item_response_model_voice_category import SpeechHistoryItemResponseModelVoiceCategory
from .speech_to_text_character_response_model import SpeechToTextCharacterResponseModel
from .speech_to_text_chunk_response_model import SpeechToTextChunkResponseModel
from .speech_to_text_webhook_response_model import SpeechToTextWebhookResponseModel
from .speech_to_text_word_response_model import SpeechToTextWordResponseModel
from .speech_to_text_word_response_model_type import SpeechToTextWordResponseModelType
from .srt_export_options import SrtExportOptions
from .start_pvc_voice_training_response_model import StartPvcVoiceTrainingResponseModel
from .start_speaker_separation_response_model import StartSpeakerSeparationResponseModel
from .streaming_audio_chunk_with_timestamps_response import StreamingAudioChunkWithTimestampsResponse
from .subscription import Subscription
from .subscription_extras_response_model import SubscriptionExtrasResponseModel
from .subscription_response import SubscriptionResponse
from .subscription_response_model_billing_period import SubscriptionResponseModelBillingPeriod
from .subscription_response_model_character_refresh_period import SubscriptionResponseModelCharacterRefreshPeriod
from .subscription_response_model_currency import SubscriptionResponseModelCurrency
from .subscription_status_type import SubscriptionStatusType
from .subscription_usage_response_model import SubscriptionUsageResponseModel
from .supported_voice import SupportedVoice
from .system_tool_config_input import SystemToolConfigInput
from .system_tool_config_input_params import (
    SystemToolConfigInputParams,
    SystemToolConfigInputParams_EndCall,
    SystemToolConfigInputParams_LanguageDetection,
    SystemToolConfigInputParams_PlayKeypadTouchTone,
    SystemToolConfigInputParams_SkipTurn,
    SystemToolConfigInputParams_TransferToAgent,
    SystemToolConfigInputParams_TransferToNumber,
    SystemToolConfigInputParams_VoicemailDetection,
)
from .system_tool_config_output import SystemToolConfigOutput
from .system_tool_config_output_params import (
    SystemToolConfigOutputParams,
    SystemToolConfigOutputParams_EndCall,
    SystemToolConfigOutputParams_LanguageDetection,
    SystemToolConfigOutputParams_PlayKeypadTouchTone,
    SystemToolConfigOutputParams_SkipTurn,
    SystemToolConfigOutputParams_TransferToAgent,
    SystemToolConfigOutputParams_TransferToNumber,
    SystemToolConfigOutputParams_VoicemailDetection,
)
from .telephony_provider import TelephonyProvider
from .text_to_speech_apply_text_normalization_enum import TextToSpeechApplyTextNormalizationEnum
from .text_to_speech_output_format_enum import TextToSpeechOutputFormatEnum
from .text_to_speech_stream_request import TextToSpeechStreamRequest
from .token_response_model import TokenResponseModel
from .tool import Tool
from .tool_annotations import ToolAnnotations
from .tool_mock_config import ToolMockConfig
from .tool_request_model import ToolRequestModel
from .tool_request_model_tool_config import (
    ToolRequestModelToolConfig,
    ToolRequestModelToolConfig_Client,
    ToolRequestModelToolConfig_Mcp,
    ToolRequestModelToolConfig_System,
    ToolRequestModelToolConfig_Webhook,
)
from .tool_response_model import ToolResponseModel
from .tool_response_model_tool_config import (
    ToolResponseModelToolConfig,
    ToolResponseModelToolConfig_Client,
    ToolResponseModelToolConfig_Mcp,
    ToolResponseModelToolConfig_System,
    ToolResponseModelToolConfig_Webhook,
)
from .tool_type import ToolType
from .tool_usage_stats_response_model import ToolUsageStatsResponseModel
from .tools_response_model import ToolsResponseModel
from .transfer_to_agent_tool_config import TransferToAgentToolConfig
from .transfer_to_agent_tool_result_error_model import TransferToAgentToolResultErrorModel
from .transfer_to_agent_tool_result_success_model import TransferToAgentToolResultSuccessModel
from .transfer_to_number_result_error_model import TransferToNumberResultErrorModel
from .transfer_to_number_result_sip_success_model import TransferToNumberResultSipSuccessModel
from .transfer_to_number_result_twilio_success_model import TransferToNumberResultTwilioSuccessModel
from .transfer_to_number_tool_config_input import TransferToNumberToolConfigInput
from .transfer_to_number_tool_config_output import TransferToNumberToolConfigOutput
from .transfer_type_enum import TransferTypeEnum
from .tts_conversational_config_input import TtsConversationalConfigInput
from .tts_conversational_config_output import TtsConversationalConfigOutput
from .tts_conversational_config_override import TtsConversationalConfigOverride
from .tts_conversational_config_override_config import TtsConversationalConfigOverrideConfig
from .tts_conversational_model import TtsConversationalModel
from .tts_model_family import TtsModelFamily
from .tts_optimize_streaming_latency import TtsOptimizeStreamingLatency
from .tts_output_format import TtsOutputFormat
from .turn_config import TurnConfig
from .turn_mode import TurnMode
from .twilio_outbound_call_response import TwilioOutboundCallResponse
from .txt_export_options import TxtExportOptions
from .update_audio_native_project_request import UpdateAudioNativeProjectRequest
from .update_chapter_request import UpdateChapterRequest
from .update_project_request import UpdateProjectRequest
from .update_pronunciation_dictionaries_request import UpdatePronunciationDictionariesRequest
from .update_workspace_member_response_model import UpdateWorkspaceMemberResponseModel
from .url_avatar import UrlAvatar
from .usage_aggregation_interval import UsageAggregationInterval
from .usage_characters_response_model import UsageCharactersResponseModel
from .user import User
from .user_feedback import UserFeedback
from .user_feedback_score import UserFeedbackScore
from .utterance_response_model import UtteranceResponseModel
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .verification_attempt_response import VerificationAttemptResponse
from .verified_voice_language_response_model import VerifiedVoiceLanguageResponseModel
from .verify_pvc_voice_captcha_response_model import VerifyPvcVoiceCaptchaResponseModel
from .voice import Voice
from .voice_design_preview_response import VoiceDesignPreviewResponse
from .voice_generation_parameter_option_response import VoiceGenerationParameterOptionResponse
from .voice_generation_parameter_response import VoiceGenerationParameterResponse
from .voice_mail_detection_result_success_model import VoiceMailDetectionResultSuccessModel
from .voice_preview_response_model import VoicePreviewResponseModel
from .voice_response_model_category import VoiceResponseModelCategory
from .voice_response_model_safety_control import VoiceResponseModelSafetyControl
from .voice_sample import VoiceSample
from .voice_sample_preview_response_model import VoiceSamplePreviewResponseModel
from .voice_sample_visual_waveform_response_model import VoiceSampleVisualWaveformResponseModel
from .voice_settings import VoiceSettings
from .voice_sharing_moderation_check_response_model import VoiceSharingModerationCheckResponseModel
from .voice_sharing_response import VoiceSharingResponse
from .voice_sharing_response_model_category import VoiceSharingResponseModelCategory
from .voice_sharing_state import VoiceSharingState
from .voice_verification_response import VoiceVerificationResponse
from .voicemail_detection_tool_config import VoicemailDetectionToolConfig
from .webhook_auth_method_type import WebhookAuthMethodType
from .webhook_tool_api_schema_config_input import WebhookToolApiSchemaConfigInput
from .webhook_tool_api_schema_config_input_method import WebhookToolApiSchemaConfigInputMethod
from .webhook_tool_api_schema_config_input_request_headers_value import (
    WebhookToolApiSchemaConfigInputRequestHeadersValue,
)
from .webhook_tool_api_schema_config_output import WebhookToolApiSchemaConfigOutput
from .webhook_tool_api_schema_config_output_method import WebhookToolApiSchemaConfigOutputMethod
from .webhook_tool_api_schema_config_output_request_headers_value import (
    WebhookToolApiSchemaConfigOutputRequestHeadersValue,
)
from .webhook_tool_config_input import WebhookToolConfigInput
from .webhook_tool_config_output import WebhookToolConfigOutput
from .webhook_usage_type import WebhookUsageType
from .websocket_tts_client_message_multi import WebsocketTtsClientMessageMulti
from .websocket_tts_server_message_multi import WebsocketTtsServerMessageMulti
from .widget_config import WidgetConfig
from .widget_config_input_avatar import (
    WidgetConfigInputAvatar,
    WidgetConfigInputAvatar_Image,
    WidgetConfigInputAvatar_Orb,
    WidgetConfigInputAvatar_Url,
)
from .widget_config_output_avatar import (
    WidgetConfigOutputAvatar,
    WidgetConfigOutputAvatar_Image,
    WidgetConfigOutputAvatar_Orb,
    WidgetConfigOutputAvatar_Url,
)
from .widget_config_response import WidgetConfigResponse
from .widget_config_response_model_avatar import (
    WidgetConfigResponseModelAvatar,
    WidgetConfigResponseModelAvatar_Image,
    WidgetConfigResponseModelAvatar_Orb,
    WidgetConfigResponseModelAvatar_Url,
)
from .widget_expandable import WidgetExpandable
from .widget_feedback_mode import WidgetFeedbackMode
from .widget_language_preset import WidgetLanguagePreset
from .widget_language_preset_response import WidgetLanguagePresetResponse
from .widget_placement import WidgetPlacement
from .widget_styles import WidgetStyles
from .widget_text_contents import WidgetTextContents
from .workflow_tool_edge_step_model import WorkflowToolEdgeStepModel
from .workflow_tool_max_iterations_exceeded_step_model import WorkflowToolMaxIterationsExceededStepModel
from .workflow_tool_nested_tools_step_model_input import WorkflowToolNestedToolsStepModelInput
from .workflow_tool_nested_tools_step_model_input_results_item import WorkflowToolNestedToolsStepModelInputResultsItem
from .workflow_tool_nested_tools_step_model_output import WorkflowToolNestedToolsStepModelOutput
from .workflow_tool_nested_tools_step_model_output_results_item import WorkflowToolNestedToolsStepModelOutputResultsItem
from .workflow_tool_response_model_input import WorkflowToolResponseModelInput
from .workflow_tool_response_model_input_steps_item import (
    WorkflowToolResponseModelInputStepsItem,
    WorkflowToolResponseModelInputStepsItem_Edge,
    WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded,
    WorkflowToolResponseModelInputStepsItem_NestedTools,
)
from .workflow_tool_response_model_output import WorkflowToolResponseModelOutput
from .workflow_tool_response_model_output_steps_item import (
    WorkflowToolResponseModelOutputStepsItem,
    WorkflowToolResponseModelOutputStepsItem_Edge,
    WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded,
    WorkflowToolResponseModelOutputStepsItem_NestedTools,
)
from .workspace_api_key_list_response_model import WorkspaceApiKeyListResponseModel
from .workspace_api_key_response_model import WorkspaceApiKeyResponseModel
from .workspace_api_key_response_model_permissions_item import WorkspaceApiKeyResponseModelPermissionsItem
from .workspace_batch_calls_response import WorkspaceBatchCallsResponse
from .workspace_create_api_key_response_model import WorkspaceCreateApiKeyResponseModel
from .workspace_group_by_name_response_model import WorkspaceGroupByNameResponseModel
from .workspace_resource_type import WorkspaceResourceType
from .workspace_service_account_list_response_model import WorkspaceServiceAccountListResponseModel
from .workspace_service_account_response_model import WorkspaceServiceAccountResponseModel
from .workspace_webhook_list_response_model import WorkspaceWebhookListResponseModel
from .workspace_webhook_response_model import WorkspaceWebhookResponseModel
from .workspace_webhook_usage_response_model import WorkspaceWebhookUsageResponseModel

__all__ = [
    "AddChapterResponseModel",
    "AddKnowledgeBaseResponseModel",
    "AddProjectRequest",
    "AddProjectResponseModel",
    "AddPronunciationDictionaryResponseModel",
    "AddPronunciationDictionaryResponseModelPermissionOnResource",
    "AddSharingVoiceRequest",
    "AddVoiceIvcResponseModel",
    "AddVoiceResponseModel",
    "AddWorkspaceGroupMemberResponseModel",
    "AddWorkspaceInviteResponseModel",
    "AdditionalFormatResponseModel",
    "AdditionalFormats",
    "Age",
    "AgentCallLimits",
    "AgentConfig",
    "AgentConfigOverride",
    "AgentConfigOverrideConfig",
    "AgentMetadataResponseModel",
    "AgentPlatformSettingsRequestModel",
    "AgentPlatformSettingsResponseModel",
    "AgentSimulatedChatTestResponseModel",
    "AgentSummaryResponseModel",
    "AgentTestingSettings",
    "AgentTransfer",
    "AgentWorkspaceOverridesInput",
    "AgentWorkspaceOverridesOutput",
    "Alignment",
    "AllowlistItem",
    "ArrayJsonSchemaPropertyInput",
    "ArrayJsonSchemaPropertyInputItems",
    "ArrayJsonSchemaPropertyOutput",
    "ArrayJsonSchemaPropertyOutputItems",
    "AsrConversationalConfig",
    "AsrInputFormat",
    "AsrProvider",
    "AsrQuality",
    "AudioNativeCreateProjectResponseModel",
    "AudioNativeEditContentResponseModel",
    "AudioNativeProjectSettingsResponseModel",
    "AudioNativeProjectSettingsResponseModelStatus",
    "AudioOutput",
    "AudioOutputMulti",
    "AudioWithTimestampsResponse",
    "AuthConnectionLocator",
    "AuthSettings",
    "AuthorizationMethod",
    "BadRequestErrorBody",
    "BanReasonType",
    "BatchCallDetailedResponse",
    "BatchCallRecipientStatus",
    "BatchCallResponse",
    "BatchCallStatus",
    "BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostAge",
    "BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostGender",
    "BreakdownTypes",
    "BuiltInToolsInput",
    "BuiltInToolsOutput",
    "CaptionStyleCharacterAnimationModel",
    "CaptionStyleCharacterAnimationModelEnterType",
    "CaptionStyleCharacterAnimationModelExitType",
    "CaptionStyleHorizontalPlacementModel",
    "CaptionStyleHorizontalPlacementModelAlign",
    "CaptionStyleModel",
    "CaptionStyleModelTextAlign",
    "CaptionStyleModelTextStyle",
    "CaptionStyleModelTextWeight",
    "CaptionStyleSectionAnimationModel",
    "CaptionStyleSectionAnimationModelEnterType",
    "CaptionStyleSectionAnimationModelExitType",
    "CaptionStyleTemplateModel",
    "CaptionStyleVerticalPlacementModel",
    "CaptionStyleVerticalPlacementModelAlign",
    "CaptionStyleWordAnimationModel",
    "CaptionStyleWordAnimationModelEnterType",
    "CaptionStyleWordAnimationModelExitType",
    "ChapterContentBlockExtendableNodeResponseModel",
    "ChapterContentBlockInputModel",
    "ChapterContentBlockInputModelSubType",
    "ChapterContentBlockResponseModel",
    "ChapterContentBlockResponseModelNodesItem",
    "ChapterContentBlockResponseModelNodesItem_Other",
    "ChapterContentBlockResponseModelNodesItem_TtsNode",
    "ChapterContentBlockTtsNodeResponseModel",
    "ChapterContentInputModel",
    "ChapterContentParagraphTtsNodeInputModel",
    "ChapterContentResponseModel",
    "ChapterResponse",
    "ChapterSnapshotExtendedResponseModel",
    "ChapterSnapshotResponse",
    "ChapterSnapshotsResponse",
    "ChapterState",
    "ChapterStatisticsResponse",
    "ChapterWithContentResponseModel",
    "ChapterWithContentResponseModelState",
    "CharacterAlignmentModel",
    "CharacterAlignmentResponseModel",
    "CharacterUsageResponse",
    "ClientEvent",
    "ClientToolConfigInput",
    "ClientToolConfigOutput",
    "CloseConnection",
    "CloseContext",
    "CloseSocket",
    "ConvAiDynamicVariable",
    "ConvAiSecretLocator",
    "ConvAiStoredSecretDependencies",
    "ConvAiStoredSecretDependenciesAgentsItem",
    "ConvAiStoredSecretDependenciesAgentsItem_Available",
    "ConvAiStoredSecretDependenciesAgentsItem_Unknown",
    "ConvAiStoredSecretDependenciesToolsItem",
    "ConvAiStoredSecretDependenciesToolsItem_Available",
    "ConvAiStoredSecretDependenciesToolsItem_Unknown",
    "ConvAiUserSecretDbModel",
    "ConvAiWebhooks",
    "ConvAiWorkspaceStoredSecretConfig",
    "ConversationChargingCommonModel",
    "ConversationConfig",
    "ConversationConfigClientOverrideConfigInput",
    "ConversationConfigClientOverrideConfigOutput",
    "ConversationConfigClientOverrideInput",
    "ConversationConfigClientOverrideOutput",
    "ConversationConfigOverride",
    "ConversationConfigOverrideConfig",
    "ConversationDeletionSettings",
    "ConversationHistoryAnalysisCommonModel",
    "ConversationHistoryBatchCallModel",
    "ConversationHistoryElevenAssistantCommonModel",
    "ConversationHistoryErrorCommonModel",
    "ConversationHistoryEvaluationCriteriaResultCommonModel",
    "ConversationHistoryFeedbackCommonModel",
    "ConversationHistoryMetadataCommonModel",
    "ConversationHistoryMetadataCommonModelPhoneCall",
    "ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking",
    "ConversationHistoryMetadataCommonModelPhoneCall_Twilio",
    "ConversationHistoryRagUsageCommonModel",
    "ConversationHistorySipTrunkingPhoneCallModel",
    "ConversationHistorySipTrunkingPhoneCallModelDirection",
    "ConversationHistoryTranscriptCommonModelInput",
    "ConversationHistoryTranscriptCommonModelInputRole",
    "ConversationHistoryTranscriptCommonModelInputSourceMedium",
    "ConversationHistoryTranscriptCommonModelInputToolResultsItem",
    "ConversationHistoryTranscriptCommonModelOutput",
    "ConversationHistoryTranscriptCommonModelOutputRole",
    "ConversationHistoryTranscriptCommonModelOutputSourceMedium",
    "ConversationHistoryTranscriptCommonModelOutputToolResultsItem",
    "ConversationHistoryTranscriptOtherToolsResultCommonModel",
    "ConversationHistoryTranscriptOtherToolsResultCommonModelType",
    "ConversationHistoryTranscriptSystemToolResultCommonModel",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_EndCallSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_LanguageDetectionSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_SkipTurnSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberSipSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberTwilioSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_VoicemailDetectionSuccess",
    "ConversationHistoryTranscriptToolCallClientDetails",
    "ConversationHistoryTranscriptToolCallCommonModel",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Client",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Mcp",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Webhook",
    "ConversationHistoryTranscriptToolCallMcpDetails",
    "ConversationHistoryTranscriptToolCallWebhookDetails",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput",
    "ConversationHistoryTwilioPhoneCallModel",
    "ConversationHistoryTwilioPhoneCallModelDirection",
    "ConversationInitiationClientDataConfigInput",
    "ConversationInitiationClientDataConfigOutput",
    "ConversationInitiationClientDataInternal",
    "ConversationInitiationClientDataInternalDynamicVariablesValue",
    "ConversationInitiationClientDataRequestInput",
    "ConversationInitiationClientDataRequestInputDynamicVariablesValue",
    "ConversationInitiationClientDataRequestOutput",
    "ConversationInitiationClientDataRequestOutputDynamicVariablesValue",
    "ConversationInitiationClientDataWebhook",
    "ConversationInitiationClientDataWebhookRequestHeadersValue",
    "ConversationInitiationSource",
    "ConversationInitiationSourceInfo",
    "ConversationSignedUrlResponseModel",
    "ConversationSimulationSpecification",
    "ConversationSimulationSpecificationDynamicVariablesValue",
    "ConversationSummaryResponseModel",
    "ConversationSummaryResponseModelDirection",
    "ConversationSummaryResponseModelStatus",
    "ConversationTokenDbModel",
    "ConversationTokenPurpose",
    "ConversationTurnMetrics",
    "ConversationalConfig",
    "ConvertChapterResponseModel",
    "ConvertProjectResponseModel",
    "CreateAgentResponseModel",
    "CreateAudioNativeProjectRequest",
    "CreatePhoneNumberResponseModel",
    "CreatePreviouslyGeneratedVoiceRequest",
    "CreatePronunciationDictionaryResponseModel",
    "CreateSipTrunkPhoneNumberRequest",
    "CreateTranscriptRequest",
    "CreateTwilioPhoneNumberRequest",
    "CustomLlm",
    "CustomLlmRequestHeadersValue",
    "DashboardCallSuccessChartModel",
    "DashboardCriteriaChartModel",
    "DashboardDataCollectionChartModel",
    "DataCollectionResultCommonModel",
    "DeleteChapterRequest",
    "DeleteChapterResponseModel",
    "DeleteDubbingResponseModel",
    "DeleteHistoryItemResponse",
    "DeleteProjectRequest",
    "DeleteProjectResponseModel",
    "DeleteSampleResponse",
    "DeleteVoiceResponseModel",
    "DeleteVoiceSampleResponseModel",
    "DeleteWorkspaceGroupMemberResponseModel",
    "DeleteWorkspaceInviteResponseModel",
    "DeleteWorkspaceMemberResponseModel",
    "DependentAvailableAgentIdentifier",
    "DependentAvailableAgentIdentifierAccessLevel",
    "DependentAvailableToolIdentifier",
    "DependentAvailableToolIdentifierAccessLevel",
    "DependentPhoneNumberIdentifier",
    "DependentUnknownAgentIdentifier",
    "DependentUnknownToolIdentifier",
    "DialogueInput",
    "DialogueInputResponseModel",
    "DoDubbingResponse",
    "DocumentUsageModeEnum",
    "DocxExportOptions",
    "DubbedSegment",
    "DubbingMediaMetadata",
    "DubbingMediaReference",
    "DubbingMetadataPageResponseModel",
    "DubbingMetadataResponse",
    "DubbingRenderResponseModel",
    "DubbingResource",
    "DynamicVariableAssignment",
    "DynamicVariableUpdateCommonModel",
    "DynamicVariablesConfig",
    "DynamicVariablesConfigDynamicVariablePlaceholdersValue",
    "EditChapterResponseModel",
    "EditProjectResponseModel",
    "EditVoiceResponseModel",
    "EditVoiceSettingsRequest",
    "EditVoiceSettingsResponseModel",
    "EmbedVariant",
    "EmbeddingModelEnum",
    "EndCallToolConfig",
    "EndCallToolResultModel",
    "EvaluationSettings",
    "EvaluationSuccessResult",
    "ExportOptions",
    "ExportOptions_Docx",
    "ExportOptions_Html",
    "ExportOptions_Pdf",
    "ExportOptions_SegmentedJson",
    "ExportOptions_Srt",
    "ExportOptions_Txt",
    "ExtendedSubscriptionResponseModelBillingPeriod",
    "ExtendedSubscriptionResponseModelCharacterRefreshPeriod",
    "ExtendedSubscriptionResponseModelCurrency",
    "FeatureStatusCommonModel",
    "FeaturesUsageCommonModel",
    "FeedbackItem",
    "FinalOutput",
    "FinalOutputMulti",
    "FineTuningResponse",
    "FineTuningResponseModelStateValue",
    "FlushContext",
    "ForcedAlignmentCharacterResponseModel",
    "ForcedAlignmentResponseModel",
    "ForcedAlignmentWordResponseModel",
    "Gender",
    "GenerateVoiceRequest",
    "GenerationConfig",
    "GetAgentEmbedResponseModel",
    "GetAgentKnowledgebaseSizeResponseModel",
    "GetAgentLinkResponseModel",
    "GetAgentResponseModel",
    "GetAgentResponseModelPhoneNumbersItem",
    "GetAgentResponseModelPhoneNumbersItem_SipTrunk",
    "GetAgentResponseModelPhoneNumbersItem_Twilio",
    "GetAgentsPageResponseModel",
    "GetAudioNativeProjectSettingsResponseModel",
    "GetChapterRequest",
    "GetChapterSnapshotsRequest",
    "GetChaptersRequest",
    "GetChaptersResponse",
    "GetConvAiDashboardSettingsResponseModel",
    "GetConvAiDashboardSettingsResponseModelChartsItem",
    "GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess",
    "GetConvAiDashboardSettingsResponseModelChartsItem_Criteria",
    "GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection",
    "GetConvAiSettingsResponseModel",
    "GetConversationResponseModel",
    "GetConversationResponseModelStatus",
    "GetConversationsPageResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown",
    "GetKnowledgeBaseFileResponseModel",
    "GetKnowledgeBaseListResponseModel",
    "GetKnowledgeBaseListResponseModelDocumentsItem",
    "GetKnowledgeBaseListResponseModelDocumentsItem_File",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Text",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Url",
    "GetKnowledgeBaseSummaryFileResponseModel",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryTextResponseModel",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryUrlResponseModel",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseTextResponseModel",
    "GetKnowledgeBaseUrlResponseModel",
    "GetLibraryVoicesResponse",
    "GetPhoneNumberInboundSipTrunkConfigResponseModel",
    "GetPhoneNumberOutboundSipTrunkConfigResponseModel",
    "GetPhoneNumberResponse",
    "GetPhoneNumberSipTrunkResponseModel",
    "GetPhoneNumberTwilioResponseModel",
    "GetProjectRequest",
    "GetProjectsRequest",
    "GetProjectsResponse",
    "GetPronunciationDictionariesMetadataResponseModel",
    "GetPronunciationDictionariesResponse",
    "GetPronunciationDictionaryMetadataResponse",
    "GetPronunciationDictionaryMetadataResponseModelPermissionOnResource",
    "GetPronunciationDictionaryResponse",
    "GetSpeechHistoryResponse",
    "GetToolDependentAgentsResponseModel",
    "GetToolDependentAgentsResponseModelAgentsItem",
    "GetToolDependentAgentsResponseModelAgentsItem_Available",
    "GetToolDependentAgentsResponseModelAgentsItem_Unknown",
    "GetVoicesResponse",
    "GetVoicesV2Response",
    "GetWorkspaceSecretsResponseModel",
    "HistoryAlignmentResponseModel",
    "HistoryAlignmentsResponseModel",
    "HistoryItemResponse",
    "HtmlExportOptions",
    "HttpValidationError",
    "ImageAvatar",
    "InboundSipTrunkConfigRequestModel",
    "InitialiseContext",
    "InitializeConnection",
    "InitializeConnectionMulti",
    "IntegrationType",
    "InvoiceResponse",
    "KeepContextAlive",
    "KnowledgeBaseDocumentChunkResponseModel",
    "KnowledgeBaseDocumentMetadataResponseModel",
    "KnowledgeBaseDocumentType",
    "KnowledgeBaseLocator",
    "LanguageAddedResponse",
    "LanguageDetectionToolConfig",
    "LanguageDetectionToolResultModel",
    "LanguagePresetInput",
    "LanguagePresetOutput",
    "LanguagePresetTranslation",
    "LanguageResponse",
    "LibraryVoiceResponse",
    "LibraryVoiceResponseModelCategory",
    "ListMcpToolsResponseModel",
    "LiteralJsonSchemaProperty",
    "LiteralJsonSchemaPropertyConstantValue",
    "LiteralJsonSchemaPropertyType",
    "Llm",
    "LlmCategoryUsage",
    "LlmInputOutputTokensUsage",
    "LlmTokensCategoryUsage",
    "LlmUsageCalculatorLlmResponseModel",
    "LlmUsageCalculatorResponseModel",
    "LlmUsageInput",
    "LlmUsageOutput",
    "ManualVerificationFileResponse",
    "ManualVerificationResponse",
    "McpApprovalPolicy",
    "McpServerConfigInput",
    "McpServerConfigInputRequestHeadersValue",
    "McpServerConfigInputSecretToken",
    "McpServerConfigInputUrl",
    "McpServerConfigOutput",
    "McpServerConfigOutputRequestHeadersValue",
    "McpServerConfigOutputSecretToken",
    "McpServerConfigOutputUrl",
    "McpServerMetadataResponseModel",
    "McpServerResponseModel",
    "McpServerResponseModelDependentAgentsItem",
    "McpServerResponseModelDependentAgentsItem_Available",
    "McpServerResponseModelDependentAgentsItem_Unknown",
    "McpServerTransport",
    "McpServersResponseModel",
    "McpToolApprovalHash",
    "McpToolApprovalPolicy",
    "MetricRecord",
    "MetricType",
    "Model",
    "ModelRatesResponseModel",
    "ModelResponseModelConcurrencyGroup",
    "ModelSettingsResponseModel",
    "ModerationStatusResponseModel",
    "ModerationStatusResponseModelSafetyStatus",
    "ModerationStatusResponseModelWarningStatus",
    "MultichannelSpeechToTextResponseModel",
    "MusicPrompt",
    "NormalizedAlignment",
    "ObjectJsonSchemaPropertyInput",
    "ObjectJsonSchemaPropertyInputPropertiesValue",
    "ObjectJsonSchemaPropertyOutput",
    "ObjectJsonSchemaPropertyOutputPropertiesValue",
    "OrbAvatar",
    "OutboundCallRecipient",
    "OutboundCallRecipientResponseModel",
    "OutboundSipTrunkConfigRequestModel",
    "OutputFormat",
    "PdfExportOptions",
    "PhoneNumberAgentInfo",
    "PhoneNumberTransfer",
    "PhoneNumberTransferDestination",
    "PhoneNumberTransferTransferDestination",
    "PhoneNumberTransferTransferDestination_Phone",
    "PhoneNumberTransferTransferDestination_SipUri",
    "PlayDtmfResultErrorModel",
    "PlayDtmfResultSuccessModel",
    "PlayDtmfToolConfig",
    "PodcastBulletinMode",
    "PodcastBulletinModeData",
    "PodcastConversationMode",
    "PodcastConversationModeData",
    "PodcastProjectResponseModel",
    "PodcastTextSource",
    "PodcastUrlSource",
    "PostAgentAvatarResponseModel",
    "PostWorkspaceSecretResponseModel",
    "PrivacyConfig",
    "ProjectCreationMetaResponseModel",
    "ProjectCreationMetaResponseModelStatus",
    "ProjectCreationMetaResponseModelType",
    "ProjectExtendedResponse",
    "ProjectExtendedResponseModelAccessLevel",
    "ProjectExtendedResponseModelApplyTextNormalization",
    "ProjectExtendedResponseModelFiction",
    "ProjectExtendedResponseModelQualityPreset",
    "ProjectExtendedResponseModelSourceType",
    "ProjectExtendedResponseModelTargetAudience",
    "ProjectResponse",
    "ProjectResponseModelAccessLevel",
    "ProjectResponseModelFiction",
    "ProjectResponseModelSourceType",
    "ProjectResponseModelTargetAudience",
    "ProjectSnapshotExtendedResponseModel",
    "ProjectSnapshotResponse",
    "ProjectSnapshotsResponse",
    "ProjectState",
    "PromptAgent",
    "PromptAgentApiModelInput",
    "PromptAgentApiModelInputToolsItem",
    "PromptAgentApiModelInputToolsItem_Client",
    "PromptAgentApiModelInputToolsItem_Mcp",
    "PromptAgentApiModelInputToolsItem_System",
    "PromptAgentApiModelInputToolsItem_Webhook",
    "PromptAgentApiModelOutput",
    "PromptAgentApiModelOutputToolsItem",
    "PromptAgentApiModelOutputToolsItem_Client",
    "PromptAgentApiModelOutputToolsItem_Mcp",
    "PromptAgentApiModelOutputToolsItem_System",
    "PromptAgentApiModelOutputToolsItem_Webhook",
    "PromptAgentApiModelOverride",
    "PromptAgentApiModelOverrideConfig",
    "PromptAgentDbModel",
    "PromptEvaluationCriteria",
    "PronunciationDictionaryAliasRuleRequestModel",
    "PronunciationDictionaryLocator",
    "PronunciationDictionaryLocatorResponseModel",
    "PronunciationDictionaryPhonemeRuleRequestModel",
    "PronunciationDictionaryRulesResponseModel",
    "PronunciationDictionaryVersionLocator",
    "PronunciationDictionaryVersionResponseModel",
    "PronunciationDictionaryVersionResponseModelPermissionOnResource",
    "PydanticPronunciationDictionaryVersionLocator",
    "QueryParamsJsonSchema",
    "RagChunkMetadata",
    "RagConfig",
    "RagDocumentIndexResponseModel",
    "RagDocumentIndexUsage",
    "RagDocumentIndexesResponseModel",
    "RagIndexOverviewEmbeddingModelResponseModel",
    "RagIndexOverviewResponseModel",
    "RagIndexStatus",
    "RagRetrievalInfo",
    "ReaderResourceResponseModel",
    "ReaderResourceResponseModelResourceType",
    "RealtimeVoiceSettings",
    "RecordingResponse",
    "RemoveMemberFromGroupRequest",
    "Render",
    "RenderStatus",
    "RenderType",
    "RequestPvcManualVerificationResponseModel",
    "ResourceAccessInfo",
    "ResourceAccessInfoRole",
    "ResourceMetadataResponseModel",
    "ReviewStatus",
    "SafetyCommonModel",
    "SafetyEvaluation",
    "SafetyResponseModel",
    "SafetyRule",
    "SaveVoicePreviewRequest",
    "SecretDependencyType",
    "SegmentCreateResponse",
    "SegmentDeleteResponse",
    "SegmentDubResponse",
    "SegmentSubtitleFrame",
    "SegmentTranscriptionResponse",
    "SegmentTranslationResponse",
    "SegmentUpdateResponse",
    "SegmentedJsonExportOptions",
    "SendText",
    "SendTextMulti",
    "ShareOptionResponseModel",
    "ShareOptionResponseModelType",
    "SimilarVoice",
    "SimilarVoiceCategory",
    "SimilarVoicesForSpeakerResponse",
    "SipMediaEncryptionEnum",
    "SipTrunkCredentialsRequestModel",
    "SipTrunkOutboundCallResponse",
    "SipTrunkTransportEnum",
    "SipUriTransferDestination",
    "SkipTurnToolConfig",
    "SkipTurnToolResponseModel",
    "SongSection",
    "SpeakerAudioResponseModel",
    "SpeakerResponseModel",
    "SpeakerSegment",
    "SpeakerSeparationResponseModel",
    "SpeakerSeparationResponseModelStatus",
    "SpeakerTrack",
    "SpeakerUpdatedResponse",
    "SpeechHistoryItemResponse",
    "SpeechHistoryItemResponseModelSource",
    "SpeechHistoryItemResponseModelVoiceCategory",
    "SpeechToTextCharacterResponseModel",
    "SpeechToTextChunkResponseModel",
    "SpeechToTextWebhookResponseModel",
    "SpeechToTextWordResponseModel",
    "SpeechToTextWordResponseModelType",
    "SrtExportOptions",
    "StartPvcVoiceTrainingResponseModel",
    "StartSpeakerSeparationResponseModel",
    "StreamingAudioChunkWithTimestampsResponse",
    "Subscription",
    "SubscriptionExtrasResponseModel",
    "SubscriptionResponse",
    "SubscriptionResponseModelBillingPeriod",
    "SubscriptionResponseModelCharacterRefreshPeriod",
    "SubscriptionResponseModelCurrency",
    "SubscriptionStatusType",
    "SubscriptionUsageResponseModel",
    "SupportedVoice",
    "SystemToolConfigInput",
    "SystemToolConfigInputParams",
    "SystemToolConfigInputParams_EndCall",
    "SystemToolConfigInputParams_LanguageDetection",
    "SystemToolConfigInputParams_PlayKeypadTouchTone",
    "SystemToolConfigInputParams_SkipTurn",
    "SystemToolConfigInputParams_TransferToAgent",
    "SystemToolConfigInputParams_TransferToNumber",
    "SystemToolConfigInputParams_VoicemailDetection",
    "SystemToolConfigOutput",
    "SystemToolConfigOutputParams",
    "SystemToolConfigOutputParams_EndCall",
    "SystemToolConfigOutputParams_LanguageDetection",
    "SystemToolConfigOutputParams_PlayKeypadTouchTone",
    "SystemToolConfigOutputParams_SkipTurn",
    "SystemToolConfigOutputParams_TransferToAgent",
    "SystemToolConfigOutputParams_TransferToNumber",
    "SystemToolConfigOutputParams_VoicemailDetection",
    "TelephonyProvider",
    "TextToSpeechApplyTextNormalizationEnum",
    "TextToSpeechOutputFormatEnum",
    "TextToSpeechStreamRequest",
    "TokenResponseModel",
    "Tool",
    "ToolAnnotations",
    "ToolMockConfig",
    "ToolRequestModel",
    "ToolRequestModelToolConfig",
    "ToolRequestModelToolConfig_Client",
    "ToolRequestModelToolConfig_Mcp",
    "ToolRequestModelToolConfig_System",
    "ToolRequestModelToolConfig_Webhook",
    "ToolResponseModel",
    "ToolResponseModelToolConfig",
    "ToolResponseModelToolConfig_Client",
    "ToolResponseModelToolConfig_Mcp",
    "ToolResponseModelToolConfig_System",
    "ToolResponseModelToolConfig_Webhook",
    "ToolType",
    "ToolUsageStatsResponseModel",
    "ToolsResponseModel",
    "TransferToAgentToolConfig",
    "TransferToAgentToolResultErrorModel",
    "TransferToAgentToolResultSuccessModel",
    "TransferToNumberResultErrorModel",
    "TransferToNumberResultSipSuccessModel",
    "TransferToNumberResultTwilioSuccessModel",
    "TransferToNumberToolConfigInput",
    "TransferToNumberToolConfigOutput",
    "TransferTypeEnum",
    "TtsConversationalConfigInput",
    "TtsConversationalConfigOutput",
    "TtsConversationalConfigOverride",
    "TtsConversationalConfigOverrideConfig",
    "TtsConversationalModel",
    "TtsModelFamily",
    "TtsOptimizeStreamingLatency",
    "TtsOutputFormat",
    "TurnConfig",
    "TurnMode",
    "TwilioOutboundCallResponse",
    "TxtExportOptions",
    "UpdateAudioNativeProjectRequest",
    "UpdateChapterRequest",
    "UpdateProjectRequest",
    "UpdatePronunciationDictionariesRequest",
    "UpdateWorkspaceMemberResponseModel",
    "UrlAvatar",
    "UsageAggregationInterval",
    "UsageCharactersResponseModel",
    "User",
    "UserFeedback",
    "UserFeedbackScore",
    "UtteranceResponseModel",
    "ValidationError",
    "ValidationErrorLocItem",
    "VerificationAttemptResponse",
    "VerifiedVoiceLanguageResponseModel",
    "VerifyPvcVoiceCaptchaResponseModel",
    "Voice",
    "VoiceDesignPreviewResponse",
    "VoiceGenerationParameterOptionResponse",
    "VoiceGenerationParameterResponse",
    "VoiceMailDetectionResultSuccessModel",
    "VoicePreviewResponseModel",
    "VoiceResponseModelCategory",
    "VoiceResponseModelSafetyControl",
    "VoiceSample",
    "VoiceSamplePreviewResponseModel",
    "VoiceSampleVisualWaveformResponseModel",
    "VoiceSettings",
    "VoiceSharingModerationCheckResponseModel",
    "VoiceSharingResponse",
    "VoiceSharingResponseModelCategory",
    "VoiceSharingState",
    "VoiceVerificationResponse",
    "VoicemailDetectionToolConfig",
    "WebhookAuthMethodType",
    "WebhookToolApiSchemaConfigInput",
    "WebhookToolApiSchemaConfigInputMethod",
    "WebhookToolApiSchemaConfigInputRequestHeadersValue",
    "WebhookToolApiSchemaConfigOutput",
    "WebhookToolApiSchemaConfigOutputMethod",
    "WebhookToolApiSchemaConfigOutputRequestHeadersValue",
    "WebhookToolConfigInput",
    "WebhookToolConfigOutput",
    "WebhookUsageType",
    "WebsocketTtsClientMessageMulti",
    "WebsocketTtsServerMessageMulti",
    "WidgetConfig",
    "WidgetConfigInputAvatar",
    "WidgetConfigInputAvatar_Image",
    "WidgetConfigInputAvatar_Orb",
    "WidgetConfigInputAvatar_Url",
    "WidgetConfigOutputAvatar",
    "WidgetConfigOutputAvatar_Image",
    "WidgetConfigOutputAvatar_Orb",
    "WidgetConfigOutputAvatar_Url",
    "WidgetConfigResponse",
    "WidgetConfigResponseModelAvatar",
    "WidgetConfigResponseModelAvatar_Image",
    "WidgetConfigResponseModelAvatar_Orb",
    "WidgetConfigResponseModelAvatar_Url",
    "WidgetExpandable",
    "WidgetFeedbackMode",
    "WidgetLanguagePreset",
    "WidgetLanguagePresetResponse",
    "WidgetPlacement",
    "WidgetStyles",
    "WidgetTextContents",
    "WorkflowToolEdgeStepModel",
    "WorkflowToolMaxIterationsExceededStepModel",
    "WorkflowToolNestedToolsStepModelInput",
    "WorkflowToolNestedToolsStepModelInputResultsItem",
    "WorkflowToolNestedToolsStepModelOutput",
    "WorkflowToolNestedToolsStepModelOutputResultsItem",
    "WorkflowToolResponseModelInput",
    "WorkflowToolResponseModelInputStepsItem",
    "WorkflowToolResponseModelInputStepsItem_Edge",
    "WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded",
    "WorkflowToolResponseModelInputStepsItem_NestedTools",
    "WorkflowToolResponseModelOutput",
    "WorkflowToolResponseModelOutputStepsItem",
    "WorkflowToolResponseModelOutputStepsItem_Edge",
    "WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded",
    "WorkflowToolResponseModelOutputStepsItem_NestedTools",
    "WorkspaceApiKeyListResponseModel",
    "WorkspaceApiKeyResponseModel",
    "WorkspaceApiKeyResponseModelPermissionsItem",
    "WorkspaceBatchCallsResponse",
    "WorkspaceCreateApiKeyResponseModel",
    "WorkspaceGroupByNameResponseModel",
    "WorkspaceResourceType",
    "WorkspaceServiceAccountListResponseModel",
    "WorkspaceServiceAccountResponseModel",
    "WorkspaceWebhookListResponseModel",
    "WorkspaceWebhookResponseModel",
    "WorkspaceWebhookUsageResponseModel",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .speech_to_speech_convert_request_file_format import SpeechToSpeechConvertRequestFileFormat
from .speech_to_speech_convert_request_output_format import SpeechToSpeechConvertRequestOutputFormat
from .speech_to_speech_stream_request_file_format import SpeechToSpeechStreamRequestFileFormat
from .speech_to_speech_stream_request_output_format import SpeechToSpeechStreamRequestOutputFormat

__all__ = [
    "SpeechToSpeechConvertRequestFileFormat",
    "SpeechToSpeechConvertRequestOutputFormat",
    "SpeechToSpeechStreamRequestFileFormat",
    "SpeechToSpeechStreamRequestOutputFormat",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.get_knowledge_base_list_response_model import GetKnowledgeBaseListResponseModel
from ...types.knowledge_base_document_type import KnowledgeBaseDocumentType
from .document.client import AsyncDocumentClient, DocumentClient
from .documents.client import AsyncDocumentsClient, DocumentsClient
from .raw_client import AsyncRawKnowledgeBaseClient, RawKnowledgeBaseClient


class KnowledgeBaseClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawKnowledgeBaseClient(client_wrapper=client_wrapper)
        self.documents = DocumentsClient(client_wrapper=client_wrapper)

        self.document = DocumentClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawKnowledgeBaseClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawKnowledgeBaseClient
        """
        return self._raw_client

    def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        search: typing.Optional[str] = None,
        show_only_owned_documents: typing.Optional[bool] = None,
        types: typing.Optional[
            typing.Union[KnowledgeBaseDocumentType, typing.Sequence[KnowledgeBaseDocumentType]]
        ] = None,
        use_typesense: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetKnowledgeBaseListResponseModel:
        """
        Get a list of available knowledge base documents

        Parameters
        ----------
        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        page_size : typing.Optional[int]
            How many documents to return at maximum. Can not exceed 100, defaults to 30.

        search : typing.Optional[str]
            If specified, the endpoint returns only such knowledge base documents whose names start with this string.

        show_only_owned_documents : typing.Optional[bool]
            If set to true, the endpoint will return only documents owned by you (and not shared from somebody else).

        types : typing.Optional[typing.Union[KnowledgeBaseDocumentType, typing.Sequence[KnowledgeBaseDocumentType]]]
            If present, the endpoint will return only documents of the given types.

        use_typesense : typing.Optional[bool]
            If set to true, the endpoint will use typesense DB to search for the documents).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetKnowledgeBaseListResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.conversational_ai.knowledge_base.list()
        """
        _response = self._raw_client.list(
            cursor=cursor,
            page_size=page_size,
            search=search,
            show_only_owned_documents=show_only_owned_documents,
            types=types,
            use_typesense=use_typesense,
            request_options=request_options,
        )
        return _response.data


class AsyncKnowledgeBaseClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawKnowledgeBaseClient(client_wrapper=client_wrapper)
        self.documents = AsyncDocumentsClient(client_wrapper=client_wrapper)

        self.document = AsyncDocumentClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawKnowledgeBaseClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawKnowledgeBaseClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        search: typing.Optional[str] = None,
        show_only_owned_documents: typing.Optional[bool] = None,
        types: typing.Optional[
            typing.Union[KnowledgeBaseDocumentType, typing.Sequence[KnowledgeBaseDocumentType]]
        ] = None,
        use_typesense: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetKnowledgeBaseListResponseModel:
        """
        Get a list of available knowledge base documents

        Parameters
        ----------
        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        page_size : typing.Optional[int]
            How many documents to return at maximum. Can not exceed 100, defaults to 30.

        search : typing.Optional[str]
            If specified, the endpoint returns only such knowledge base documents whose names start with this string.

        show_only_owned_documents : typing.Optional[bool]
            If set to true, the endpoint will return only documents owned by you (and not shared from somebody else).

        types : typing.Optional[typing.Union[KnowledgeBaseDocumentType, typing.Sequence[KnowledgeBaseDocumentType]]]
            If present, the endpoint will return only documents of the given types.

        use_typesense : typing.Optional[bool]
            If set to true, the endpoint will use typesense DB to search for the documents).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetKnowledgeBaseListResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.conversational_ai.knowledge_base.list()


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            cursor=cursor,
            page_size=page_size,
            search=search,
            show_only_owned_documents=show_only_owned_documents,
            types=types,
            use_typesense=use_typesense,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import json
import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.additional_formats import AdditionalFormats
from ..types.http_validation_error import HttpValidationError
from .types.speech_to_text_convert_request_file_format import SpeechToTextConvertRequestFileFormat
from .types.speech_to_text_convert_request_timestamps_granularity import SpeechToTextConvertRequestTimestampsGranularity
from .types.speech_to_text_convert_request_webhook_metadata import SpeechToTextConvertRequestWebhookMetadata
from .types.speech_to_text_convert_response import SpeechToTextConvertResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawSpeechToTextClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def convert(
        self,
        *,
        model_id: str,
        enable_logging: typing.Optional[bool] = None,
        file: typing.Optional[core.File] = OMIT,
        language_code: typing.Optional[str] = OMIT,
        tag_audio_events: typing.Optional[bool] = OMIT,
        num_speakers: typing.Optional[int] = OMIT,
        timestamps_granularity: typing.Optional[SpeechToTextConvertRequestTimestampsGranularity] = OMIT,
        diarize: typing.Optional[bool] = OMIT,
        diarization_threshold: typing.Optional[float] = OMIT,
        additional_formats: typing.Optional[AdditionalFormats] = OMIT,
        file_format: typing.Optional[SpeechToTextConvertRequestFileFormat] = OMIT,
        cloud_storage_url: typing.Optional[str] = OMIT,
        webhook: typing.Optional[bool] = OMIT,
        webhook_id: typing.Optional[str] = OMIT,
        temperature: typing.Optional[float] = OMIT,
        seed: typing.Optional[int] = OMIT,
        use_multi_channel: typing.Optional[bool] = OMIT,
        webhook_metadata: typing.Optional[SpeechToTextConvertRequestWebhookMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SpeechToTextConvertResponse]:
        """
        Transcribe an audio or video file. If webhook is set to true, the request will be processed asynchronously and results sent to configured webhooks. When use_multi_channel is true and the provided audio has multiple channels, a 'transcripts' object with separate transcripts for each channel is returned. Otherwise, returns a single transcript. The optional webhook_metadata parameter allows you to attach custom data that will be included in webhook responses for request correlation and tracking.

        Parameters
        ----------
        model_id : str
            The ID of the model to use for transcription, currently only 'scribe_v1' and 'scribe_v1_experimental' are available.

        enable_logging : typing.Optional[bool]
            When enable_logging is set to false zero retention mode will be used for the request. This will mean history features are unavailable for this request, including request stitching. Zero retention mode may only be used by enterprise customers.

        file : typing.Optional[core.File]
            See core.File for more documentation

        language_code : typing.Optional[str]
            An ISO-639-1 or ISO-639-3 language_code corresponding to the language of the audio file. Can sometimes improve transcription performance if known beforehand. Defaults to null, in this case the language is predicted automatically.

        tag_audio_events : typing.Optional[bool]
            Whether to tag audio events like (laughter), (footsteps), etc. in the transcription.

        num_speakers : typing.Optional[int]
            The maximum amount of speakers talking in the uploaded file. Can help with predicting who speaks when. The maximum amount of speakers that can be predicted is 32. Defaults to null, in this case the amount of speakers is set to the maximum value the model supports.

        timestamps_granularity : typing.Optional[SpeechToTextConvertRequestTimestampsGranularity]
            The granularity of the timestamps in the transcription. 'word' provides word-level timestamps and 'character' provides character-level timestamps per word.

        diarize : typing.Optional[bool]
            Whether to annotate which speaker is currently talking in the uploaded file.

        diarization_threshold : typing.Optional[float]
            Diarization threshold to apply during speaker diarization. A higher value means there will be a lower chance of one speaker being diarized as two different speakers but also a higher chance of two different speakers being diarized as one speaker (less total speakers predicted). A low value means there will be a higher chance of one speaker being diarized as two different speakers but also a lower chance of two different speakers being diarized as one speaker (more total speakers predicted). Can only be set when diarize=True and num_speakers=None. Defaults to None, in which case we will choose a threshold based on the model_id (0.22 usually).

        additional_formats : typing.Optional[AdditionalFormats]
            A list of additional formats to export the transcript to.

        file_format : typing.Optional[SpeechToTextConvertRequestFileFormat]
            The format of input audio. Options are 'pcm_s16le_16' or 'other' For `pcm_s16le_16`, the input audio must be 16-bit PCM at a 16kHz sample rate, single channel (mono), and little-endian byte order. Latency will be lower than with passing an encoded waveform.

        cloud_storage_url : typing.Optional[str]
            The valid AWS S3, Cloudflare R2 or Google Cloud Storage URL of the file to transcribe. Exactly one of the file or cloud_storage_url parameters must be provided. The file must be a valid publicly accessible cloud storage URL. The file size must be less than 2GB. URL can be pre-signed.

        webhook : typing.Optional[bool]
            Whether to send the transcription result to configured speech-to-text webhooks.  If set the request will return early without the transcription, which will be delivered later via webhook.

        webhook_id : typing.Optional[str]
            Optional specific webhook ID to send the transcription result to. Only valid when webhook is set to true. If not provided, transcription will be sent to all configured speech-to-text webhooks.

        temperature : typing.Optional[float]
            Controls the randomness of the transcription output. Accepts values between 0.0 and 2.0, where higher values result in more diverse and less deterministic results. If omitted, we will use a temperature based on the model you selected which is usually 0.

        seed : typing.Optional[int]
            If specified, our system will make a best effort to sample deterministically, such that repeated requests with the same seed and parameters should return the same result. Determinism is not guaranteed. Must be an integer between 0 and 2147483647.

        use_multi_channel : typing.Optional[bool]
            Whether the audio file contains multiple channels where each channel contains a single speaker. When enabled, each channel will be transcribed independently and the results will be combined. Each word in the response will include a 'channel_index' field indicating which channel it was spoken on. A maximum of 5 channels is supported.

        webhook_metadata : typing.Optional[SpeechToTextConvertRequestWebhookMetadata]
            Optional metadata to be included in the webhook response. This should be a JSON string representing an object with a maximum depth of 2 levels and maximum size of 16KB. Useful for tracking internal IDs, job references, or other contextual information.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SpeechToTextConvertResponse]
            Synchronous transcription result
        """
        _response = self._client_wrapper.httpx_client.request(
            "v1/speech-to-text",
            method="POST",
            params={
                "enable_logging": enable_logging,
            },
            data={
                "model_id": model_id,
                "language_code": language_code,
                "tag_audio_events": tag_audio_events,
                "num_speakers": num_speakers,
                "timestamps_granularity": timestamps_granularity,
                "diarize": diarize,
                "diarization_threshold": diarization_threshold,
                "file_format": file_format,
                "cloud_storage_url": cloud_storage_url,
                "webhook": webhook,
                "webhook_id": webhook_id,
                "temperature": temperature,
                "seed": seed,
                "use_multi_channel": use_multi_channel,
                "webhook_metadata": webhook_metadata,
            },
            files={
                **({"file": file} if file is not None else {}),
                **(
                    {"additional_formats": (None, json.dumps(jsonable_encoder(additional_formats)), "application/json")}
                    if additional_formats is not OMIT
                    else {}
                ),
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SpeechToTextConvertResponse,
                    construct_type(
                        type_=SpeechToTextConvertResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawSpeechToTextClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def convert(
        self,
        *,
        model_id: str,
        enable_logging: typing.Optional[bool] = None,
        file: typing.Optional[core.File] = OMIT,
        language_code: typing.Optional[str] = OMIT,
        tag_audio_events: typing.Optional[bool] = OMIT,
        num_speakers: typing.Optional[int] = OMIT,
        timestamps_granularity: typing.Optional[SpeechToTextConvertRequestTimestampsGranularity] = OMIT,
        diarize: typing.Optional[bool] = OMIT,
        diarization_threshold: typing.Optional[float] = OMIT,
        additional_formats: typing.Optional[AdditionalFormats] = OMIT,
        file_format: typing.Optional[SpeechToTextConvertRequestFileFormat] = OMIT,
        cloud_storage_url: typing.Optional[str] = OMIT,
        webhook: typing.Optional[bool] = OMIT,
        webhook_id: typing.Optional[str] = OMIT,
        temperature: typing.Optional[float] = OMIT,
        seed: typing.Optional[int] = OMIT,
        use_multi_channel: typing.Optional[bool] = OMIT,
        webhook_metadata: typing.Optional[SpeechToTextConvertRequestWebhookMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SpeechToTextConvertResponse]:
        """
        Transcribe an audio or video file. If webhook is set to true, the request will be processed asynchronously and results sent to configured webhooks. When use_multi_channel is true and the provided audio has multiple channels, a 'transcripts' object with separate transcripts for each channel is returned. Otherwise, returns a single transcript. The optional webhook_metadata parameter allows you to attach custom data that will be included in webhook responses for request correlation and tracking.

        Parameters
        ----------
        model_id : str
            The ID of the model to use for transcription, currently only 'scribe_v1' and 'scribe_v1_experimental' are available.

        enable_logging : typing.Optional[bool]
            When enable_logging is set to false zero retention mode will be used for the request. This will mean history features are unavailable for this request, including request stitching. Zero retention mode may only be used by enterprise customers.

        file : typing.Optional[core.File]
            See core.File for more documentation

        language_code : typing.Optional[str]
            An ISO-639-1 or ISO-639-3 language_code corresponding to the language of the audio file. Can sometimes improve transcription performance if known beforehand. Defaults to null, in this case the language is predicted automatically.

        tag_audio_events : typing.Optional[bool]
            Whether to tag audio events like (laughter), (footsteps), etc. in the transcription.

        num_speakers : typing.Optional[int]
            The maximum amount of speakers talking in the uploaded file. Can help with predicting who speaks when. The maximum amount of speakers that can be predicted is 32. Defaults to null, in this case the amount of speakers is set to the maximum value the model supports.

        timestamps_granularity : typing.Optional[SpeechToTextConvertRequestTimestampsGranularity]
            The granularity of the timestamps in the transcription. 'word' provides word-level timestamps and 'character' provides character-level timestamps per word.

        diarize : typing.Optional[bool]
            Whether to annotate which speaker is currently talking in the uploaded file.

        diarization_threshold : typing.Optional[float]
            Diarization threshold to apply during speaker diarization. A higher value means there will be a lower chance of one speaker being diarized as two different speakers but also a higher chance of two different speakers being diarized as one speaker (less total speakers predicted). A low value means there will be a higher chance of one speaker being diarized as two different speakers but also a lower chance of two different speakers being diarized as one speaker (more total speakers predicted). Can only be set when diarize=True and num_speakers=None. Defaults to None, in which case we will choose a threshold based on the model_id (0.22 usually).

        additional_formats : typing.Optional[AdditionalFormats]
            A list of additional formats to export the transcript to.

        file_format : typing.Optional[SpeechToTextConvertRequestFileFormat]
            The format of input audio. Options are 'pcm_s16le_16' or 'other' For `pcm_s16le_16`, the input audio must be 16-bit PCM at a 16kHz sample rate, single channel (mono), and little-endian byte order. Latency will be lower than with passing an encoded waveform.

        cloud_storage_url : typing.Optional[str]
            The valid AWS S3, Cloudflare R2 or Google Cloud Storage URL of the file to transcribe. Exactly one of the file or cloud_storage_url parameters must be provided. The file must be a valid publicly accessible cloud storage URL. The file size must be less than 2GB. URL can be pre-signed.

        webhook : typing.Optional[bool]
            Whether to send the transcription result to configured speech-to-text webhooks.  If set the request will return early without the transcription, which will be delivered later via webhook.

        webhook_id : typing.Optional[str]
            Optional specific webhook ID to send the transcription result to. Only valid when webhook is set to true. If not provided, transcription will be sent to all configured speech-to-text webhooks.

        temperature : typing.Optional[float]
            Controls the randomness of the transcription output. Accepts values between 0.0 and 2.0, where higher values result in more diverse and less deterministic results. If omitted, we will use a temperature based on the model you selected which is usually 0.

        seed : typing.Optional[int]
            If specified, our system will make a best effort to sample deterministically, such that repeated requests with the same seed and parameters should return the same result. Determinism is not guaranteed. Must be an integer between 0 and 2147483647.

        use_multi_channel : typing.Optional[bool]
            Whether the audio file contains multiple channels where each channel contains a single speaker. When enabled, each channel will be transcribed independently and the results will be combined. Each word in the response will include a 'channel_index' field indicating which channel it was spoken on. A maximum of 5 channels is supported.

        webhook_metadata : typing.Optional[SpeechToTextConvertRequestWebhookMetadata]
            Optional metadata to be included in the webhook response. This should be a JSON string representing an object with a maximum depth of 2 levels and maximum size of 16KB. Useful for tracking internal IDs, job references, or other contextual information.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SpeechToTextConvertResponse]
            Synchronous transcription result
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v1/speech-to-text",
            method="POST",
            params={
                "enable_logging": enable_logging,
            },
            data={
                "model_id": model_id,
                "language_code": language_code,
                "tag_audio_events": tag_audio_events,
                "num_speakers": num_speakers,
                "timestamps_granularity": timestamps_granularity,
                "diarize": diarize,
                "diarization_threshold": diarization_threshold,
                "file_format": file_format,
                "cloud_storage_url": cloud_storage_url,
                "webhook": webhook,
                "webhook_id": webhook_id,
                "temperature": temperature,
                "seed": seed,
                "use_multi_channel": use_multi_channel,
                "webhook_metadata": webhook_metadata,
            },
            files={
                **({"file": file} if file is not None else {}),
                **(
                    {"additional_formats": (None, json.dumps(jsonable_encoder(additional_formats)), "application/json")}
                    if additional_formats is not OMIT
                    else {}
                ),
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SpeechToTextConvertResponse,
                    construct_type(
                        type_=SpeechToTextConvertResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class VerifiedVoiceLanguageResponseModel(UncheckedBaseModel):
    language: str = pydantic.Field()
    """
    The language of the voice.
    """

    model_id: str = pydantic.Field()
    """
    The voice's model ID.
    """

    accent: typing.Optional[str] = pydantic.Field(default=None)
    """
    The voice's accent, if applicable.
    """

    locale: typing.Optional[str] = pydantic.Field(default=None)
    """
    The voice's locale, if applicable.
    """

    preview_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The voice's preview URL, if applicable.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.audio_native_create_project_response_model import AudioNativeCreateProjectResponseModel
from ..types.audio_native_edit_content_response_model import AudioNativeEditContentResponseModel
from ..types.get_audio_native_project_settings_response_model import GetAudioNativeProjectSettingsResponseModel
from .raw_client import AsyncRawAudioNativeClient, RawAudioNativeClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class AudioNativeClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawAudioNativeClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawAudioNativeClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawAudioNativeClient
        """
        return self._raw_client

    def create(
        self,
        *,
        name: str,
        image: typing.Optional[str] = OMIT,
        author: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        small: typing.Optional[bool] = OMIT,
        text_color: typing.Optional[str] = OMIT,
        background_color: typing.Optional[str] = OMIT,
        sessionization: typing.Optional[int] = OMIT,
        voice_id: typing.Optional[str] = OMIT,
        model_id: typing.Optional[str] = OMIT,
        file: typing.Optional[core.File] = OMIT,
        auto_convert: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudioNativeCreateProjectResponseModel:
        """
        Creates Audio Native enabled project, optionally starts conversion and returns project ID and embeddable HTML snippet.

        Parameters
        ----------
        name : str
            Project name.

        image : typing.Optional[str]
            (Deprecated) Image URL used in the player. If not provided, default image set in the Player settings is used.

        author : typing.Optional[str]
            Author used in the player and inserted at the start of the uploaded article. If not provided, the default author set in the Player settings is used.

        title : typing.Optional[str]
            Title used in the player and inserted at the top of the uploaded article. If not provided, the default title set in the Player settings is used.

        small : typing.Optional[bool]
            (Deprecated) Whether to use small player or not. If not provided, default value set in the Player settings is used.

        text_color : typing.Optional[str]
            Text color used in the player. If not provided, default text color set in the Player settings is used.

        background_color : typing.Optional[str]
            Background color used in the player. If not provided, default background color set in the Player settings is used.

        sessionization : typing.Optional[int]
            (Deprecated) Specifies for how many minutes to persist the session across page reloads. If not provided, default sessionization set in the Player settings is used.

        voice_id : typing.Optional[str]
            Voice ID used to voice the content. If not provided, default voice ID set in the Player settings is used.

        model_id : typing.Optional[str]
            TTS Model ID used in the player. If not provided, default model ID set in the Player settings is used.

        file : typing.Optional[core.File]
            See core.File for more documentation

        auto_convert : typing.Optional[bool]
            Whether to auto convert the project to audio or not.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudioNativeCreateProjectResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.audio_native.create(
            name="name",
        )
        """
        _response = self._raw_client.create(
            name=name,
            image=image,
            author=author,
            title=title,
            small=small,
            text_color=text_color,
            background_color=background_color,
            sessionization=sessionization,
            voice_id=voice_id,
            model_id=model_id,
            file=file,
            auto_convert=auto_convert,
            request_options=request_options,
        )
        return _response.data

    def get_settings(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetAudioNativeProjectSettingsResponseModel:
        """
        Get player settings for the specific project.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetAudioNativeProjectSettingsResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.audio_native.get_settings(
            project_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._raw_client.get_settings(project_id, request_options=request_options)
        return _response.data

    def update(
        self,
        project_id: str,
        *,
        file: typing.Optional[core.File] = OMIT,
        auto_convert: typing.Optional[bool] = OMIT,
        auto_publish: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudioNativeEditContentResponseModel:
        """
        Updates content for the specific AudioNative Project.

        Parameters
        ----------
        project_id : str
            The ID of the project to be used. You can use the [List projects](/docs/api-reference/studio/get-projects) endpoint to list all the available projects.

        file : typing.Optional[core.File]
            See core.File for more documentation

        auto_convert : typing.Optional[bool]
            Whether to auto convert the project to audio or not.

        auto_publish : typing.Optional[bool]
            Whether to auto publish the new project snapshot after it's converted.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudioNativeEditContentResponseModel
            Successful Response

        Examples
        --------
        from elevenlabs import ElevenLabs

        client = ElevenLabs(
            api_key="YOUR_API_KEY",
        )
        client.audio_native.update(
            project_id="21m00Tcm4TlvDq8ikWAM",
        )
        """
        _response = self._raw_client.update(
            project_id, file=file, auto_convert=auto_convert, auto_publish=auto_publish, request_options=request_options
        )
        return _response.data


class AsyncAudioNativeClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawAudioNativeClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawAudioNativeClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawAudioNativeClient
        """
        return self._raw_client

    async def create(
        self,
        *,
        name: str,
        image: typing.Optional[str] = OMIT,
        author: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        small: typing.Optional[bool] = OMIT,
        text_color: typing.Optional[str] = OMIT,
        background_color: typing.Optional[str] = OMIT,
        sessionization: typing.Optional[int] = OMIT,
        voice_id: typing.Optional[str] = OMIT,
        model_id: typing.Optional[str] = OMIT,
        file: typing.Optional[core.File] = OMIT,
        auto_convert: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudioNativeCreateProjectResponseModel:
        """
        Creates Audio Native enabled project, optionally starts conversion and returns project ID and embeddable HTML snippet.

        Parameters
        ----------
        name : str
            Project name.

        image : typing.Optional[str]
            (Deprecated) Image URL used in the player. If not provided, default image set in the Player settings is used.

        author : typing.Optional[str]
            Author used in the player and inserted at the start of the uploaded article. If not provided, the default author set in the Player settings is used.

        title : typing.Optional[str]
            Title used in the player and inserted at the top of the uploaded article. If not provided, the default title set in the Player settings is used.

        small : typing.Optional[bool]
            (Deprecated) Whether to use small player or not. If not provided, default value set in the Player settings is used.

        text_color : typing.Optional[str]
            Text color used in the player. If not provided, default text color set in the Player settings is used.

        background_color : typing.Optional[str]
            Background color used in the player. If not provided, default background color set in the Player settings is used.

        sessionization : typing.Optional[int]
            (Deprecated) Specifies for how many minutes to persist the session across page reloads. If not provided, default sessionization set in the Player settings is used.

        voice_id : typing.Optional[str]
            Voice ID used to voice the content. If not provided, default voice ID set in the Player settings is used.

        model_id : typing.Optional[str]
            TTS Model ID used in the player. If not provided, default model ID set in the Player settings is used.

        file : typing.Optional[core.File]
            See core.File for more documentation

        auto_convert : typing.Optional[bool]
            Whether to auto convert the project to audio or not.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudioNativeCreateProjectResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.audio_native.create(
                name="name",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            name=name,
            image=image,
            author=author,
            title=title,
            small=small,
            text_color=text_color,
            background_color=background_color,
            sessionization=sessionization,
            voice_id=voice_id,
            model_id=model_id,
            file=file,
            auto_convert=auto_convert,
            request_options=request_options,
        )
        return _response.data

    async def get_settings(
        self, project_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetAudioNativeProjectSettingsResponseModel:
        """
        Get player settings for the specific project.

        Parameters
        ----------
        project_id : str
            The ID of the Studio project.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetAudioNativeProjectSettingsResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.audio_native.get_settings(
                project_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_settings(project_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        project_id: str,
        *,
        file: typing.Optional[core.File] = OMIT,
        auto_convert: typing.Optional[bool] = OMIT,
        auto_publish: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AudioNativeEditContentResponseModel:
        """
        Updates content for the specific AudioNative Project.

        Parameters
        ----------
        project_id : str
            The ID of the project to be used. You can use the [List projects](/docs/api-reference/studio/get-projects) endpoint to list all the available projects.

        file : typing.Optional[core.File]
            See core.File for more documentation

        auto_convert : typing.Optional[bool]
            Whether to auto convert the project to audio or not.

        auto_publish : typing.Optional[bool]
            Whether to auto publish the new project snapshot after it's converted.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AudioNativeEditContentResponseModel
            Successful Response

        Examples
        --------
        import asyncio

        from elevenlabs import AsyncElevenLabs

        client = AsyncElevenLabs(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.audio_native.update(
                project_id="21m00Tcm4TlvDq8ikWAM",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            project_id, file=file, auto_convert=auto_convert, auto_publish=auto_publish, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .dynamic_variable_assignment import DynamicVariableAssignment
from .system_tool_config_output_params import SystemToolConfigOutputParams


class SystemToolConfigOutput(UncheckedBaseModel):
    """
    A system tool is a tool that is used to call a system method in the server
    """

    name: str
    description: str
    response_timeout_secs: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum time in seconds to wait for the tool call to complete.
    """

    disable_interruptions: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, the user will not be able to interrupt the agent while this tool is running.
    """

    force_pre_tool_speech: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, the agent will speak before the tool call.
    """

    assignments: typing.Optional[typing.List[DynamicVariableAssignment]] = pydantic.Field(default=None)
    """
    Configuration for extracting values from tool responses and assigning them to dynamic variables
    """

    params: SystemToolConfigOutputParams

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .batch_call_status import BatchCallStatus
from .telephony_provider import TelephonyProvider


class BatchCallResponse(UncheckedBaseModel):
    id: str
    phone_number_id: str
    phone_provider: typing.Optional[TelephonyProvider] = None
    name: str
    agent_id: str
    created_at_unix: int
    scheduled_time_unix: int
    total_calls_dispatched: int
    total_calls_scheduled: int
    last_updated_at_unix: int
    status: BatchCallStatus
    agent_name: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
